/*
 * This file is part of ARSnova Mobile.
 * Copyright (C) 2011-2012 Christian Thomas Weber
 * Copyright (C) 2012-2016 The ARSnova Team
 *
 * ARSnova Mobile is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * ARSnova Mobile is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with ARSnova Mobile.  If not, see <http://www.gnu.org/licenses/>.
 */
(function (exports) {
	"use strict";
	// Android browser return always English as language, even when your phone is set up with a different one. Because of
	// that, we read here the user agent and we extract from there the phone language. For all the other devices,
	// "navigator.language" should give as the correct language.
	var ua = navigator.userAgent.toLowerCase();
	var isAndroid = ua.indexOf("android") > -1;
	var isChrome = ua.indexOf("chrome") > -1;
	var lang;
	var Messages;

	if (isAndroid && !isChrome && navigator.userAgent &&
			(lang = navigator.userAgent.match(/android.*\W(\w\w)-(\w\w)\W/i))) {
		lang = lang[1];
	} else {
		try {
			lang = localStorage.getItem("language");
		} catch (e) {}

		if (!lang) {
			/* navigator.languages is preferred since navigator.language stores the UI
			 * language instead of the user preference in some browsers. */
			lang = navigator.languages && navigator.languages.length > 0 ?
				navigator.languages[0] :
				navigator.language;
		}
	}

	if (lang) {
		lang = lang.substr(0, 2).toLowerCase();
	}

	switch (lang) {
		case 'de':
			moment.locale('de');
			Messages = {
				PRIVACY_MODE_WARNING_TITLE: "Privatmodus",
				PRIVACY_MODE_WARNING_TEXT: "Im Privatmodus Ihres Browsers funktioniert ARSnova leider nicht, da Ihr Browser das Beschreiben des App-Speichers verweigert. Bitte für die Dauer der Nutzung von ARSnova den Privatmodus deaktivieren und ARSnova erneut aufrufen. Ihre Anonymität bleibt auch bei deaktiviertem Privatmodus gewahrt.",
				BROWSER_NOT_SUPPORTED_MESSAGE: "Der Funktionsumfang von ARSnova wird durch Ihrem Browser möglicherweise nicht vollständig unterstützt. Die folgenden Browser werden für die Nutzung mit ARSnova empfohlen: ###.",
				UPDATE_BROWSER_MESSAGE: "Bitte aktualisieren Sie Ihren ###-Browser, um ARSnova verwenden zu können.",
				SESSION_IS_CLOSED: "Die Session \"###\" ist momentan geschlossen.",
				FEATURE_COMING_SOON: "Feature kommt in Kürze.",

				/* rolePanel */
				BLOG: "Blog",
				STUDENT: "Student/in",
				SPEAKER: "Dozent/in",
				TITLE_ROLE: "Feedback & Interaktion",
				/* loginPanel */
				GUEST: "Gast",
				CHANGE_ROLE: "Rolle wechseln",
				NO_GUEST_SPEAKER: "Hinweis: Um eine Session anzulegen, müssen Sie sich anmelden.",
				CONFIRM_GUEST_SPEAKER: "Wenn Sie sich als Gast anmelden, ist die Verwaltung der ARSnova-Session nur auf dem aktuellen Gerät möglich. Möchten Sie sich trotzdem als Gast anmelden?",
				GUEST_LOGIN: "Anmeldung",
				BACK_TO_ROLEPANEL: "Rollen",

				/* homePanel */
				LOGOUT: "Abmelden",
				LOGOUT_REQUEST: "Möchten Sie sich wirklich von ARSnova abmelden?",
				SESSIONID_PLACEHOLDER: "Zugangsschlüssel eingeben",
				ENTER_SESSIONID: "Bitte Session-ID eingeben",
				GO: "Session betreten",
				LOAD_MORE: "Weitere laden",
				YOUR_COURSE_SESSIONS: "Auswählbare Moodle-Kurse",
				LAST_VISITED_SESSIONS_SPEAKER: "Als Student/in besuchte Sessions",
				LAST_VISITED_SESSIONS_STUDENT: "Besuchte Sessions",
				LEGEND: "Bedeutung der Farben",
				OPEN_SESSION: "Offene Session",
				CLOSED_SESSION: "Gesperrte Session",
				CONFIRM_CLOSE_SESSION: "Zugang wirklich sperren?",
				CONFIRM_CLOSE_SESSION_MESSAGE: "Wenn Sie den Zugang sperren, können nur noch aktuell angemeldete Studierende teilnehmen.",
				ON_SESSION_CREATION_1: "Es wurde der Zugangsschlüssel «###» für Ihre Session erzeugt. Dieser kann jederzeit auf der Session-Übersicht eingesehen werden. Bitte teilen Sie ihn Ihren Studierenden mit.",
				ON_SESSION_CREATION_2: "Sie können diese Session nur in der Rolle Dozent/in via ### verwalten",
				ON_THIS_DEVICE: "auf diesem Gerät",
				DEMO_SESSION: "Demo-Session: ",

				/* LOAD MASK */
				LOAD_MASK: "Lade Daten...",
				LOAD_MASK_LOGIN: "Login...",
				LOAD_MASK_SAVE: 'Speichern...',
				LOAD_MASK_SEARCH: "Suche Sessions...",
				LOAD_MASK_SEARCH_QUESTIONS: "Suche Fragen...",
				LOAD_MASK_SEARCH_COURSES: "Suche Kurse...",
				LOAD_MASK_SESSION_DELETE: "Lösche Session-Daten...",
				LOAD_MASK_ACTIVATION: "Aktiviere die Freigabe...",
				LOAD_MASK_SESSION_EXPORT: "Exportiere Session-Daten...",
				LOAD_MASK_SESSION_IMPORT: "Importiere Session-Daten...",
				LOAD_MASK_SESSION_PP_CLONE: "Kopiere Public Pool Session...",
				LOAD_MASK_QUESTION_IMPORT: "Importiere Fragen...",

				/* mySessionsPanel */
				HOME: "Start",
				SESSION: "Session",
				SESSION_INFO_TITLE: "Session-Info",
				SESSION_INFO_TITLE_SHORT: "Infos",
				NEW_SESSION: "Neue Session",
				MY_SESSIONS: "Meine Sessions",
				MY_PUBLIC_POOL_SESSIONS: "Meine Pool-Sessions",
				SESSIONS: "Sessions",
				SESSIONID_WILL_BE_CREATED: "Session-ID wird erzeugt...",
				SESSION_NAME: "Langname",
				SESSION_NAME_PLACEHOLDER: "max. 50 Zeichen",
				SESSION_SHORT_NAME: "Kurzname",
				SESSION_SHORT_NAME_PLACEHOLDER: "max. 8 Zeichen",
				SESSION_SAVE: "Session anlegen",
				SESSION_OPTIONAL_INFO: "Informationen zur Session",
				SAVE: "Speichern",

				/* MESSAGE OF THE DAY */
				MESSAGEOFTHEDAY: "\"Message of the Day\"",
				MESSAGEOFTHEDAY_BUTTON:	"Message of the Day",
				CREATE_NEW_MOTD: "Neue Nachricht anlegen",
				MY_MESSAGES: "Zurück",
				NEW_MOTD: "Neue Nachricht",
				SAVE_NEW_MESSAGE: "Speichern",
				EDIT_MOTD: "Nachricht bearbeiten",
				DELETE_MESSAGE: "Nachricht löschen",
				MOTD_MANAGEMENT: "Nachrichten verwalten",
				MOTD_TITLE: "Schlagzeile",
				MOTD_TEXT: "Nachricht",
				MOTD_AUDIENCE: "Zielgruppe",
				MOTD_AUDIENCE_CHOOSE: "Zielgruppe auswählen",
				MOTD_AUDIENCE_ALL: "Alle",
				MOTD_AUDIENCE_LOGGEDIN: "Alle eingeloggten Benutzer/innen",
				MOTD_AUDIENCE_TUTORS: "Lehrende",
				MOTD_AUDIENCE_STUDENTS: "Studierende",
				MOTD_AUDIENCE_SESSION: "Session",
				MOTD_STARTDATE: "Anzeigenstart",
				MOTD_ENDDATE: "Anzeigenende",
				MOTD_NOTIFICATION_TITLE: "Keinen Titel angegeben",
				MOTD_NOTIFICATION_TEXT: "Keinen Text angegeben",
				MOTD_NOTIFICATION_STARTDATE: "Keinen Startzeitpunkt angegeben",
				MOTD_NOTIFICATION_ENDDATE: "Keinen Endzeitpunkt angegeben",

				/* feedback */
				ABCD_TITLE: "A|B|C|D",
				FEEDBACK: "Feedback",
				MY_FEEDBACK: "Mein Feedback",
				RESET_FEEDBACK: 'Zurücksetzen',
				FEEDBACK_GOOD: "Bitte schneller",
				FEEDBACK_OKAY: "Kann folgen",
				FEEDBACK_BAD: "Zu schnell",
				FEEDBACK_NONE: "Abgehängt",
				FEEDBACK_VOTE: "Feedback",
				FEEDBACK_RESET: "Ihr Feedback wurde zurückgesetzt",
				QUESTION_TO_SPEAKER: "Feedback",
				QUESTION_INSTRUCTION: "Sie stellen diese Frage anonym",
				QUESTION_TEXT: "Fragetext",
				QUESTION_TEXT_PLACEHOLDER: "Nur die Lehrperson sieht Ihre Frage. Sobald die Lehrperson Ihre Frage gelesen hat, wird sie grau angezeigt. Antworten können in ARSnova nicht gegeben werden. Sie können auf Ihre Fragen nur in dem Browser zugreifen, den Sie gerade verwenden.",
				QUESTION_SUBJECT: "Thema",
				QUESTION_SUBJECT_PLACEHOLDER: "erscheint in der Übersicht, max. 50 Zeichen",
				QUESTION_SAVED: 'Ihre Frage wurde gespeichert',
				NOTIFICATION: "Hinweis",
				TRANSMISSION_ERROR: "Die Übermittlung der Frage war leider nicht erfolgreich",
				QUESTION_CREATION_ERROR: "Das Erstellen der Frage war leider nicht erfolgreich",
				QUESTION_EDIT_ERROR: "Das Editieren der Frage war leider nicht erfolgreich",
				ANSWER_CREATION_ERROR: "Die Antwort konnte leider nicht gespeichert werden",
				RELEASE_VOTE_ERROR: "Die Freigabe der Abstimmung war leider nicht erfolgreich",
				SEND: "Abschicken",

				/* questions */
				QUESTION: "Frage",
				QUESTION_PLACEHOLDER: "Frage eingeben",
				QUESTIONTEXT_PLACEHOLDER: "Frage eingeben",
				QUESTION_MANAGEMENT: "Fragenverwaltung",
				QUESTIONS: "Fragen",
				TASKS: "Aufgaben",
				QUESTION_DETAILS: "Volltext",
				QUESTION_DATE: "Datum",
				DELETE: "Löschen",
				EDIT: "Bearbeiten",
				CANCEL: "Abbrechen",
				DURATION: "Dauer",
				SUBMIT_ANSWER: "Antwort abschicken?",
				NO_QUESTIONS: "Keine Fragen vorhanden",
				NO_UNLOCKED_QUESTIONS: "Es gibt vorbereitete Fragen, diese sind aber noch nicht freigeschaltet.",
				LOADING_NEW_QUESTIONS: "Lade neue Fragen",
				NO_DATE: "Kein Datum",
				NO_SUBJECT: "Kein Thema",
				SESSION_CLOSE_NOTICE: "Um mehrfaches Abstimmen zu verhindern, hat Ihr/e Dozent/in die Session gesperrt. Loggen Sie sich bitte erst am Ende der Vorlesung aus!",
				NOTICE_READ: "Ich hab's verstanden",
				STATUS: "Status",
				FREETEXT_ANSWER_TEXT: "Meine Antwort",
				FREETEXT_DETAIL_HEADER: "Antwort",
				FREETEXT_DETAIL_ANSWER: "Antwort",
				FORMAT_PLACEHOLDER: "Text",
				NO_ANSWERS: "Keine Antworten vorhanden",
				ONLY_ABSTENTION_ANSWERS: "Es gibt ###, aber bisher keine Antworten.",
				FREETEXT_DETAIL_LABEL: "Es gibt ### und %%%:",
				ANSWER_SAVED: "Ihre Antwort wurde gespeichert",
				MISSING_INPUT: "Es müssen alle Felder ausgefüllt werden",
				SHOWCASE: "Vorstellen",
				LEAVE: "Verlassen",
				MEMBERS_ONLY: "Diese Frage ist nur für Kursmitglieder sichtbar",
				QUESTION_RATING: "5-stufige Likert-Skala mit Auswertung",
				QUESTION_RATING_SHORT: "Skala",
				QUESTION_GRADE: "Schulnote als Antwort",
				QUESTION_GRADE_SHORT: "Benotung",
				QUESTION_GRID: "Bildmarkierungsfrage (Hot Spots im Bild)",
				QUESTION_GRID_SHORT: "Bildfrage",
				QUESTION_MC: "Multiple-Choice-Frage (Mehrfachauswahl)",
				QUESTION_MC_SHORT: "MC",
				QUESTION_YESNO: "Entscheidungsfrage",
				QUESTION_LIVE_CLICKER: "Live Clicker",
				QUESTION_YESNO_SHORT: "Ja | Nein",
				QUESTION_SINGLE_CHOICE: "Single-Choice-Frage (Einfachauswahl)",
				QUESTION_SINGLE_CHOICE_SHORT: "SC",
				QUESTION_FREETEXT: "Offene Frage (Freitextfrage)",
				QUESTION_FREETEXT_SHORT: "Freitext",
				OPEN_QUESTION: "Offene Frage",
				CLOSED_QUESTION: "Gesperrte Frage",
				CLOSED_VOTING: "Abstimmung gesperrt",
				CONFIRM_CLOSE_VOTE: "Abstimmung wirklich sperren?",
				CONFIRM_CLOSE_ALL_VOTES: "Abstimmungen wirklich sperren?",
				CONFIRM_CLOSE_QUESTION: "Frage wirklich sperren?",
				CONFIRM_CLOSE_ALL_QUESTIONS: "Fragen wirklich sperren?",
				CONFIRM_CLOSE_QUESTION_MESSAGE: "Wenn Sie die Frage sperren, können Studierende die Frage weder sehen noch beantworten.",
				CONFIRM_CLOSE_VOTE_MESSAGE: "Wenn Sie die Abstimmung sperren, können Studierende die Frage nicht mehr beantworten.",
				CONFIRM_CLOSE_ALL_VOTES_MESSAGE: "Wenn Sie die Abstimmung für alle Fragen sperren, können Studierende die Fragen nicht mehr beantworten.",
				CONFIRM_CLOSE_ALL_QUESTIONS_MESSAGE: "Wenn Sie die Fragen sperren, können Studierende die Fragen weder sehen noch beantworten.",
				SAVE_AND_CONTINUE: "Speichern und neue Frage stellen",
				PICTURE_MAX_FILESIZE: "Dateiformat: JPEG oder PNG, max. ###",
				CONFIRM_ANSWERS_CHANGED: "Bereits gegebene Antworten gehen verloren",
				QUESTION_PREVIEW_BUTTON_TITLE: "Vorschau",
				QUESTION_PREVIEW_BUTTON_TITLE_DESKTOP: "Vorschau",
				QUESTION_PREVIEW_DIALOGBOX_TITLE: "Vorschau",
				QUESTION_PREVIEW_DIALOGBOX_BUTTON_TITLE: "Vorschau schließen",
				ANSWER_PREVIEW_BUTTON_TITLE: "Vorschau",
				ANSWER_PREVIEW_DIALOGBOX_TITLE: "Vorschau",
				ANSWER_PREVIEW_DIALOGBOX_BUTTON_TITLE: "OK",
				ANSWER_POINTS: "Antwortpunkte",
				ANSWER_POINTS_CORRECT: "Richtig",
				ANSWER_POINTS_INCORRECT: "Falsch",
				NO_ANSWER_MARKED_CORRECT_MESSAGE: "Sie haben keine Antwortoption als richtig markiert.",
				NO_ANSWER_MARKED_CORRECT_OPTION_YES: "Trotzdem speichern?",
				NO_ANSWER_MARKED_CORRECT_OPTION_NO: "Abbrechen",
				ACTIVE_QUESTION_CLOSED: "Die aktive Frage wurde gesperrt",
				ACTIVE_QUESTION_VOTING_CLOSED: "Die Abstimmung für die aktive Frage wurde gesperrt",
				SESSION_PREVIEW_BUTTON_TITLE_DESKTOP: "Vorschau",
				HINT_FOR_SOLUTION: "Lösungshinweis",
				HINT_FOR_SOLUTION_EDIT: "Lösungshinweis?",
				SAMPLE_SOLUTION: "Musterlösung",

				/* sort */
				SORT_QUESTIONS_TITLE: "Fragen sortieren",
				SORT_CATEGORIES_TITLE: "Kategorien sortieren",
				SORT_CATEGORIES: "Kategorien",
				SORT_SAVED: "Sortierung wurde gespeichert",
				SORT_SAVE_AND_CONTINUE: "Speichern und fortfahren",
				SORT_TRANSMISSION_ERROR: "Das Sortieren war leider nicht erfolgreich",

				/* user */
				QUESTIONS_TO_STUDENTS: "Fragen ans Publikum",
				QUESTIONS_FROM_STUDENTS: "Fragen der Studierenden",
				UNREAD_QUESTIONS_FROM_STUDENTS: "Ungelesene Fragen",
				PREPARATION_QUESTIONS: "Vorbereitung",
				PREPARATION_QUESTIONS_LONG: "Vorbereitungsaufgaben",
				PREPARATION_QUESTION_SHORT: "Vorbereitung",
				PREPARATION_QUESTION_LONG: "Vorbereitung",
				LECTURE_QUESTIONS: "Hörsaal",
				LECTURE_QUESTION_LONG: "Hörsaalfrage",
				LECTURE_QUESTIONS_LONG: "Hörsaalfragen",
				QUESTION_REQUEST: "Ich habe eine Frage",
				FLASHCARD_SHORT: "LK",
				FLASHCARDS: "Lernkarten",
				FLASHCARD: "Lernkarte",
				MASK_ALREADY_ANSWERED: "Sie haben abgestimmt",
				MASK_IS_ABSTENTION_ANSWER: "Sie haben sich enthalten",
				MASK_CORRECT_ANSWER_IS: "Die richtige Antwort ist...",
				MASK_VOTE_CLOSED: "Abstimmung nicht freigegeben",
				ONE_NEW_LECTURE_QUESTION: "1 neue Hörsaalfrage",
				ONE_NEW_PREPARATION_QUESTION: "1 neue Vorbereitungsaufgabe",
				SEVERAL_NEW_LECTURE_QUESTIONS: '### neue Hörsaalfragen',
				SEVERAL_NEW_PREPARATION_QUESTIONS: '### neue Vorbereitungsaufgaben',
				WANNA_ANSWER: "Möchten Sie jetzt antworten?",
				THERE_ARE: "Es gibt",
				NEW_QUESTIONS: "neue Fragen.",
				MY_QUESTIONS: "Meine Fragen",
				MY_LEARNING_PROGRESS: "Mein Lernstand",
				VERSUS: "vs.",
				LEARN: "Lernen",
				LEARN_WITH_SELECTION: "Mit Auswahl lernen",
				UNANSWERED_QUESTIONS: "Offene Fragen",
				PREPARATION: "Vorbereitung",
				LECTURE: "Hörsaal",
				RESET_ALL_ANSWERS: "Alle Antworten zurücksetzen",
				SHOW_FLASHCARD_ANSWER: "Antwort anzeigen",
				HIDE_FLASHCARD_ANSWER: "Antwort ausblenden",
				IMAGE_NEEDED: "Es soll ein Bild als Antwort hochgeladen werden",
				COMPRESSING_MASK: "Ihr Bild wird komprimiert...",
				PICTURE_RIGHT_INFORMATION: ['Bitte beachten Sie, dass Sie keine Bilder verwenden, für deren Verwendung Sie keine Rechte haben (Urheberrechtsgesetz) oder die pornografische oder volksverhetzende (§130 StGB) Inhalte zeigen.\n',
						'Antwort abschicken?'
				].join('\n'),

				/* speaker */
				LIVE_FEEDBACK: "Live Feedback",
				COURSES_LEARNING_PROGRESS: "Lernstand des Kurses",
				COURSES_LEARNING_PROGRESS_SHORT: "Lernstand",
				CURRENT_VALUE: "Aktueller Wert",
				HOW_TO_CALCULATE_LEARNING_PROGRESS: "Wie soll der Lernstand berechnet werden?",
				QUESTION_BASED_PROGRESS: "Fragenbasiert",
				SCORE_BASED_PROGRESS: "Punktbasiert",
				WHICH_QUESTIONS_TO_USE_FOR_LEARNING_PROGRESS: "Welche Fragen sollen bei der Berechnung berücksichtigt werden?",
				BOTH: "Beides",
				QUESTION_BASED_PROGRESS_EXPLANATION: [
					'Mit dem fragenbasierten Lernstand sind alle Fragen gleich gewichtet, selbst wenn es für sie unterschiedliche Höchstpunktzahlen gibt. Der Lernstand berechnet sich beispielhaft wie folgt:\n',
					'Es sind 3 Fragen vorhanden, die jeweils eine maximal mögliche Punktzahl haben. Die Punkte seien 10, 20 und 30.',
					'Eine Frage gilt als korrekt beantwortet, wenn die jeweilige Maximalpunktzahl erreicht ist. Das heißt, wenn eine',
					'falsche Antwortoption gewählt wurde, werden Punkte abgezogen und die Maximalpunktzahl kann nicht mehr erreicht werden.',
					'Erreicht ein Studierender für die drei Fragen eine Punktzahl von 10, 20 und 20 wurde demnach die letzte Frage falsch beantwortet.',
					'Der individuelle Lernstand berechnet sich nach der Formel: \\\\[ l_{\\text{S}} = \\frac{\\text{Richtige Antw.}}{\\text{Fragen}} = \\frac{2}{3} \\hat{=}\\, 67\\%\\\\]\n',
					'Für den Kurs ergibt sich der Lernstand über die Anzahl der Studierenden: \\\\[l_{\\text{K}} = \\frac{\\text{Richtige Antworten}}{\\text{Fragen} \\cdot \\text{Studierende}}\\\\]'
				].join('\n'),
				SCORE_BASED_PROGRESS_EXPLANATION: [
					'Der punktbasierte Lernstand gewichtet Fragen mit mehreren richtigen Antwortoptionen stärker als Fragen mit nur einer richtigen Option. Der Lernstand berechnet sich beispielhaft wie folgt:\n',
					'Es sind 3 Fragen vorhanden, die jeweils eine maximal mögliche Punktzahl haben. Die Punkte seien 10, 20 und 30.',
					'Das bedeutet, dass ein Studierender für die Beantwortung der 3 Fragen insgesamt 60 Punkte erreichen kann.',
					'Bei Auswahl von falschen Antwortoptionen reduziert sich die erreichte Punktzahl, z.B. auf 30.',
					'Der individuelle Lernstand berechnet sich also nach der Formel: \\\\[ l_{\\text{S}} = \\frac{\\text{Erreichte Punkte}}{\\text{Mögliche Punkte}} = \\frac{30}{60} \\hat{=}\\, 50\\%\\\\]\n',
					'Für den Kurs ergibt sich der Lernstand über die Anzahl der Studierenden: \\\\[l_{\\text{K}} = \\frac{\\text{Gesamtzahl erreichter Punkte}}{\\text{Mögliche Punkte} \\cdot \\text{Studierende}}\\\\]'
				].join('\n'),
				QUESTIONS_ABBR: "Fragen",
				POINTS_ABBR: "Pkt.",
				NEW_LECTURE_QUESTION: "Neue Hörsaalfrage",
				NEW_PREPARATION_QUESTION: "Neue Vorbereitungsaufgabe",
				NEW_QUESTION_TITLE: "Frage",
				ARE_YOU_SURE: "Sind Sie sicher?",
				DELETE_QUESTION_TITLE: "Frage löschen",
				DELETE_QUESTIONS_TITLE: "Fragen löschen",
				DELETE_SESSION_TITLE: "Session löschen",
				DELETE_SESSION_NOTICE: "Es werden alle Fragen und Antworten der Session gelöscht",
				CATEGORY: "Thema",
				CATEGORY_PLACEHOLDER: "Thema",
				ABSTENTION: 'Enthaltung',
				ABSTENTIONS: 'Enthaltungen',
				ABSTENTION_POSSIBLE: 'Enthaltung möglich?',
				MY_COURSES: "Meine Kurse:",
				NO_COURSES_FOUND: "Es konnten keine Kurse gefunden werden",
				CORRECT_ANSWER: 'Welche Antwort soll als richtig gelten?',
				YES: "Ja",
				NO: "Nein",
				NONE: "Keine",
				CONTINUE: 'Weiter',
				ANSWERS: "Antworten",
				ANSWERS_SHOWN: "x angezeigt",
				ANSWER_OPTIONS: "Antwortoptionen",
				ANSWERS_STATISTICS: "Antwort-Statisiken",
				ENTER_ANSWER_OPTION: "Antwortoption",
				ANSWERS_PER_QUESTION: "Antworten pro Frage",
				ANSWER: "Antwort",
				COUNT: "Anzahl",
				CORRECT: "Richtig",
				CORRECT_PLACEHOLDER: "Richtige Antwort",
				WRONG: "Falsch",
				WRONG_PLACEHOLDER: "Falsche Antwort",
				OPTION_PLACEHOLDER: "Option",
				STATISTIC: "Statistik",
				STATISTICS: "Statistiken",
				ALL_CORRECT: "Komplett richtig",
				ALL_WRONG: "Komplett falsch",
				LEARNING_STATUS:	"Lernstand des Kurses",
				DELETE_ALL: "Alle löschen",
				DELETE_ANSWERS_REQUEST: "Antworten löschen?",
				DELETE_ALL_ANSWERS_REQUEST: "Alle Antworten löschen?",
				ALL_QUESTIONS_REMAIN: "Alle Fragen bleiben erhalten",
				QUESTION_REMAINS: "Die Frage bleibt erhalten",
				INCOMPLETE_INPUTS: "Ihre Eingaben sind unvollständig",
				DELETE_ALL_ANSWERS_INFO: "Es werden auch alle bisher gegebenen Antworten gelöscht",
				DELETE_ROUND_ANSWERS_COMPLETED: "Die Antworten der aktuellen Runde wurden gelöscht",
				RELEASE_LIVE_VOTING: "Abstimmung freigeben",
				CLOSE_LIVE_VOTING: "Abstimmung schließen",
				CHANGE_RELEASE: "Ändere die Freigabe...",
				TYPE: 'Typ',
				INFINITE: "unbegrenzt",
				MINUTE: "Minute",
				MINUTES: "Minuten",
				SECONDS: "Sekunden",
				BACK: "Zurück",
				FLASHCARD_FRONT_PAGE: "Vorderseite",
				FLASHCARD_BACK_PAGE: "Rückseite",
				SELECT_PICTURE_FS: "URL",
				SELECT_PICTURE_URL: "Bildadresse",
				SELECT_PICTURE_URL_SHORT: "URL",
				REMOVE_PICTURE: "Bild entfernen",
				CHOOSE_PICTURE: "Bild wählen",
				SEARCH_PICTURE: "Bild-Upload",
				SEARCH_PICTURE_SHORT: "Upload",
				PICTURE_SOURCE: "",
				GRID_LOADING: "Lade",
				GRID_LOAD: "Laden",
				GRID_ERROR_URL_MISSING: "Bitte geben Sie eine URL an",
				GRID_ERROR_IMAGE_NOT_LOADED: "Bild konnte nicht geladen werden",
				GRID_ERROR_FILE_SIZE: "Das verwendete Bild (%%%) überschreitet die maximale Dateigröße von ###",
				GRID_LABEL_ZOOM: "Zoom (in %)",
				GRID_LABEL_FIELD_X: "x-Achse",
				GRID_LABEL_FIELD_Y: "y-Achse",
				GRID_LABEL_HEATMAP: "Heatmap",
				GRID_LABEL_HEATMAP_SHORT: "HM",
				GRID_LABEL_SHOW_PERCENT: "Zeige Anzahl der Markierungen:",
				GRID_LABEL_INVERT_GRIDCOLORS: "Rasterfarbe invertieren",
				GRID_LABEL_CV_TRANSPARENCY: "Hintergrund einfärben",
				GRID_LABEL_ABSOLUTE: 'absolut',
				GRID_LABEL_RELATIVE: 'prozentual',
				GRID_LABEL_NONE: 'verborgen',
				GRID_LABEL_ABSOLUTE_SHORT: '#',
				GRID_LABEL_RELATIVE_SHORT: '%',
				GRID_LABEL_NONE_SHORT: 'ohne',
				GRID_LABEL_MARK_TOGGLE_ANSWERS: "Anzahl Markierung aufheben",
				GRID_LABEL_THRESHOLD_CORRECT_ANSWERS: "Wert korrekter Antworten",
				GRID_ERROR_LOADING_IMAGE_FS: 'Bild konnte nicht geladen werden',
				GRID_CONFIG_IMAGE: "Bildeinstellungen",
				GRID_CONFIG_GRID: "Rastereinstellungen",
				GRID_LABEL_REMAINING_DOTS: "Verbleibende Klebepunkte: ",
				GRID_LABEL_NUMBER_OF_DOTS: "Klebepunkte",
				GRID_LABEL_DELETE_MODERATION: "Vorlage löschen",
				ERROR: 'Hinweis',
				CORRECT_ANSWERS: "Richtige Antworten",
				SETTINGS: "",
				SETTINGS_HINT_TEXT: "Hinweis: <br>Maximale Dateigröße beträgt 150 KB",
				TEMPLATE_FOR_MODERATION: "Vorlagen zur Meinungsabfrage",
				TEMPLATE: "Vorlage",
				APPLY: "Übernehmen",
				MISSING_INPUTS: "Ihre Eingaben sind unvollständig:",
				MISSING_SUBJECT: "Das Thema fehlt",
				MISSING_QUESTION: "Der Text der Frage fehlt",
				MISSING_ANSWERS: "Es fehlen Antwortoptionen",
				MISSING_IMAGE: "Es wurde kein Bild hochgeladen",
				MISSING_FLASHCARD: "Die Rückseite ist leer",
				EXPECT_ANSWER_TEXT: "Anfügen von Text zum Bild zulassen?",

				/*Export session*/
				EXPORT_MSG: "Was möchten Sie exportieren?",
				EXPORT_SESSION_TITLE: "Session-Export",
				EXPORT_BUTTON_LABEL: "Exportieren",
				EXPORT_SESSION_TO_PUBLIC_TITLE: "Public Pool Export",
				EXPORT_FIELD_NAME: "Name",
				EXPORT_FIELD_UNI: "Hochschule",
				EXPORT_FIELD_LOGO: "Logo",
				EXPORT_FIELD_SUBJECT: "Studiengang",
				EXPORT_FIELD_LICENCE: "Lizenz",
				EXPORT_FIELD_LEVEL: "Niveau",
				EXPORT_FIELD_EMAIL: "E-Mail",
				EXPORT_FIELD_SPECIAL_FIELD: "Fachbereich",
				EXPORT_SELECTED_SESSIONS_TITLE: "Sessions exportieren",
				EXPORT_SELECTED_SESSIONS_MSG: "Wohin möchten Sie die Session(s) exportieren?",
				EXPORT_SESSION_INFORMATION: "Neben Hörsaal- und Vorbereitungsaufgaben der ausgewählten Sessions werden zusätzlich exportiert...",
				EXPORT_NOTIFICATION: "Es wurde keine Session ausgewählt",
				EXPORT_IOS_NOTIFICATION: "Ein Export kann auf iOS-Geräten nicht durchgeführt werden",
				EXPORT_BUTTON_FS: "Mein System",
				EXPORT_BUTTON_PP: "Public Pool",
				EXPORT_PP_NOTIFICATION: 'Als "Gast" können Sie keine Session in den Public Pool exportieren. Bitte melden Sie sich über einen der anderen Zugänge an.',
				EXPORT_SESSION_LABEL:	'Auswahl der Session(s), die exportiert werden:',
				/*Import session*/
				IMPORT_IOS_NOTIFICATION: "Ein Import kann auf iOS-Geräten nicht durchgeführt werden",
				IMPORT_NOT_SUPPORTED: "Der Session-Import wird für Ihren Browser nicht unterstützt",

				/*Round management*/
				POLL_MANAGEMENT: "Abstimmung",
				ROUND_MANAGEMENT: "Rundenverwaltung",
				START_FIRST_ROUND: "Starte Runde 1",
				START_SECOND_ROUND: "Starte Runde 2",
				CANCEL_DELAYED_ROUND: "Timer neu einstellen",
				END_ROUND_IMMEDIATELY: "Runde vorzeitig schließen",
				END_VOTE_IMMEDIATELY: "Abstimmung schließen",
				END_ROUND: "Beenden der Abstimmungsrunde",
				END_ROUND_WARNING: "Wenn die Runde beendet wird, sind keine Abstimmungen mehr möglich, bis eine neue Runde gestartet wird oder die Frage manuell entsperrt wird. Möchten Sie fortfahren?",
				RESET_ROUND: "Abstimmung zurücksetzen",
				RESET_ROUND_WARNING: "Wenn die Abstimmung zurückgesetzt wird, werden alle Antworten gelöscht und der Rundenzähler zurückgesetzt. Möchten Sie fortfahren?",
				RESET_ROUND_COMPLETED: "Die Abstimmung wurde zurückgesetzt",
				ONE_NEW_DELAYED_QUESTION: 'Neue zeitlich begrenzte Frage',
				ONE_NEW_DELAYED_QUESTION_ROUND1: 'Es gibt eine neue zeitlich begrenzte Frage',
				ONE_NEW_DELAYED_QUESTION_ROUND2: 'Eine Frage wurde zur zweiten Abstimmungsrunde freigegeben',
				VOTING_CLOSED: "Die Abstimmung wurde beendet",
				VOTING_OPENED: "Die Abstimmung wurde gestartet",
				START_VOTING: "Starte Abstimmung",
				FIRST_ROUND: "Runde 1",
				SECOND_ROUND: "Runde 2",
				BOTH_ROUNDS: "Runde 1|2",

				/*Markdown Editor*/
				EDITOR_VIMEO: "Vimeo",
				EDITOR_YOUTUBE: "Youtube",
				EDITOR_HYPERLINK: "Hyperlink",
				EDITOR_PICTURE: "Bild",
				EDITOR_URL: "Linkziel",
				EDITOR_TITLE: "Linktext",
				EDITOR_URL_PLACEHOLDER: "https://",
				EDITOR_TITLE_PLACEHOLDER: "angezeigter Text",
				EDITOR_EXTENDED_OPTIONS: "Erweiterte Optionen",
				EDITOR_IMAGE_POSITION: "Position",
				EDITOR_IMAGE_HEIGHT_LABEL: "Max. Höhe (Pixel)",
				EDITOR_IMAGE_WIDTH_LABEL: "Max. Breite (Pixel)",
				EDITOR_CENTER: "zentriert",
				EDITOR_RIGHT: "rechts",
				EDITOR_LEFT: "links",

				EDITOR_BOLD_TOOLTIP: "Fett",
				EDITOR_HEADER_TOOLTIP: "Überschrift",
				EDITOR_HYPERLINK_TOOLTIP: "Hyperlink",
				EDITOR_ULIST_TOOLTIP: "Unsortierte Liste",
				EDITOR_OLIST_TOOLTIP: "Sortierte Liste",
				EDITOR_LATEX_TOOLTIP: "Latex-Auszeichnung",
				EDITOR_CODE_TOOLTIP: "Code-Auszeichnung",
				EDITOR_QUOTE_TOOLTIP: "Zitat",
				EDITOR_YOUTUBE_TOOLTIP: "Youtube",
				EDITOR_VIMEO_TOOLTIP: "Vimeo",
				EDITOR_PICTURE_TOOLTIP: "Bild",
				EDITOR_INFO_TOOLTIP: "Info",

				EDITOR_INFO_HINT: "Sie können Texte innerhalb von ARSnova mithilfe von [Markdown](https://de.wikipedia.org/wiki/Markdown) auszeichnen. Die am häufigsten verwendeten Markdown Optionen werden in Form von Schaltflächen über den unterstützten Eingabefeldern angeboten. Zudem unterstützt ARSnova [GitHub Flavored Markdown](https://github.com/adam-p/markdown-here/wiki/Markdown-Cheatsheet).",

				/*Public pool*/
				SESSIONPOOL_LEVEL: "Niveau",
				SESSIONPOOL_CLONE: "Kopieren",
				SESSIONPOOL_AUTHORINFO: "Lehrperson",
				SESSIONPOOL_SESSIONINFO: "Session",
				SESSIONPOOL_LOGOINFO: "Logo",
				SESSIONPOOL_INFO: "Lernziele",
				SESSIONPOOL_COUNT_QUESTION: "Anzahl Fragen",
				SESSIONPOOL_NOTIFICATION_EMAIL: "Invalides Format",
				SESSIONPOOL_NOTIFICATION_LICENCE: "Keine gültige Lizenz",
				SESSIONPOOL_NOTIFICATION_SUBJECT: "Kein gültiges Fach",
				SESSIONPOOL_NOTIFICATION_NAME:	"Kein Name eingegeben",
				SESSIONPOOL_NOTIFICATION_UNIVERSITY: "Keine Hochschule angegeben",
				SESSIONPOOL_NOTIFICATION_SESSION_NAME:	"Kein Name für die Session angegeben",
				SESSIONPOOL_NOTIFICATION_SESSION_SHORTNAME:	"Kein Kürzel für die Session angegeben",
				SESSIONPOOL_NOTIFICATION_QUESTION_NUMBER: "Session muss mindestens eine Frage beinhalten",
				SESSIONPOOL_NOTIFICATION:	"Eingaben sind nicht korrekt",
				SESSIONPOOL_ERR_CAT_NOTFOUND: "Für diese Kategorie sind keine Sessions verfügbar",
				SESSIONPOOL_ERR_GET_NOTFOUND: "Session konnte nicht geladen werden",
				SESSIONPOOL_ERR_NO_PPSESSIONS: "Keine Sessions im Pool",
				SESSIONPOOL_ERR_PPSESSION_RIGHTS: "Sie haben nicht die Berechtigung, um Public Pool Sessions zu sehen.",
				SESSIONPOOL_ERR_GET_SESSION: "Sie haben nicht die Berechtigung, um die Session zu sehen.",
				SESSIONPOOL_TITLE: "Session Pool",
				SESSIONPOOL_VISIT:	"Besuchen",
				SESSIONPOOL_CHARACTERS: 'Zeichen',
				SESSIONPOOL_INFOS:	'Infos',

				/* question types */
				EVALUATION: "+|-",
				SCHOOL: "1-6",
				MC: "MC",
				YESNO: "J|N",
				ABCD: "SC",
				GRID: "Bild",
				FREETEXT: "Text",
				MC_LONG: "MC-Frage",
				ABCD_LONG: "SC-Frage",
				EVALUATION_LONG: "Evaluation",
				EVALUATION_ALT: "Auswertung",
				EVALUATION_QUESTIONS: "Evaluationsfragen",
				SCHOOL_LONG: 'Benotung',
				YESNO_LONG: 'Ja|Nein',
				GRID_LONG: "Hot Spots",
				FREETEXT_LONG: 'Freitext',
				BUZZWORD: "Schlagwort für",
				BUZZWORD_A: "Schlagwort für A",
				BUZZWORD_B: "Schlagwort für B",
				BUZZWORD_C: "Schlagwort für C",
				BUZZWORD_D: "Schlagwort für D",
				SCHOOL_A: "sehr gut",
				SCHOOL_B: "gut",
				SCHOOL_C: "befriedigend",
				SCHOOL_D: "ausreichend",
				SCHOOL_E: "mangelhaft",
				SCHOOL_F: "ungenügend",
				SCHOOL_NONE: "Enthaltung",
				EVALUATION_PLUSPLUS: "trifft voll zu",
				EVALUATION_PLUS: "trifft eher zu",
				EVALUATION_NEUTRAL: "weder noch",
				EVALUATION_MINUS: "trifft eher nicht zu",
				EVALUATION_MINUSMINUS: "trifft gar nicht zu",
				IMAGE_QUESTION_LBL: "Soll ein Bild als Antwort hochgeladen werden?",
				IMAGE_QUESTION_MINIATUR_VIEW: "Raster",
				IMAGE_QUESTION_HORIZONTAL_VIEW: "Horizontal",
				IMAGE_QUESTION_VERTICAL_VIEW: "Vertikal",

				/* action buttons - <br/> forces line break for consistent look */
				CREATE_NEW_SESSION: "Neue Session<br/>anlegen",
				NEW_QUESTION: "Neue Frage<br/>anlegen",
				NEW_FLASHCARD: "Lernkarte<br/>anlegen",
				NEW_TASK: "Aufgabe<br/>erstellen",
				SHOWCASE_MODE: "Frage<br/>präsentieren",
				SHOWCASE_TASK: "Aufgabe<br/>präsentieren",
				SHOWCASE_MODE_PLURAL: "Fragen<br/>präsentieren",
				SHOWCASE_TASKS: "Aufgaben<br/>präsentieren",
				SHOWCASE_FLASHCARD: "Lernkarte</br>präsentieren",
				SHOWCASE_FLASHCARDS: "Lernkarten</br>präsentieren",
				SHOWCASE_LIVE_CLICKER: "A|B|C|D<br />Frage",
				SHOW_STATISTIC: "Statistik<br/>anzeigen",
				RELEASE_STATISTIC: "Statistik<br/>freigeben",
				RELEASE_QUESTION: "Frage<br/>freigeben",
				RELEASE_VOTE: "Abstimmung<br/>freigeben",
				ACTIVATE_TIMER: "Timer<br/>aktivieren",
				RELEASE_ALL_VOTES: "Abstimmungen<br/>freigeben",
				RELEASE_ALL_QUESTIONS: "Fragen<br/>freigeben",
				STOP_QUESTION: "Frage<br/>sperren",
				STOP_ALL_QUESTIONS: "Fragen<br/>sperren",
				START_SESSION: "Zugang<br/>freigeben",
				STOP_SESSION: "Zugang<br/>sperren",
				MARK_CORRECT_ANSWER: "Lösung<br/>anzeigen",
				DELETE_QUESTION: "Frage<br/>löschen",
				DELETE_ALL_QUESTIONS: "Fragen<br/>löschen",
				DELETE_ANSWERS: "Antworten<br/>löschen",
				DELETE_SESSION: "Session<br/>löschen",
				GIVE_FEEDBACK: "Feedback<br/>geben",
				QUESTION_REQUEST_ADHOC: 'Ich habe<br/>eine Frage',
				GRID_LABEL_WEAKEN_IMAGE: "Bild<br>abschwächen",
				GRID_LABEL_SHOW_HEATMAP: "Heatmap<br>anzeigen",
				RESET_QUESTION: "Abstimmung<br>zurücksetzen",
				SWITCH_VOTING_MODE: "Zwei-Runden<br>System",
				READJUST_TIMER: "Timer neu<br>einstellen",
				SORT_QUESTIONS: "Fragen<br/>sortieren",
				SORT_ALPHABET: "Alphabet<br/>Sortierung",
				SORT_TIME: "Zeitliche<br/>Sortierung",
				SORT_RANDOM: "Zufällig<br/>anordnen",
				SORT_REVERT: "Änderung<br/>verwerfen",
				CHANGE_FEATURES: "Use Case<br/>wechseln",
				CHANGE_ROLE_BUTTONTEXT: "Rolle<br/>wechseln",

				/* about */
				MANUAL: "Anleitung",
				ABOUT: "Über",
				IMPRINT: "Impressum",
				PRIVACY: "Datenschutz",

				OPINION: "Deine Meinung ist gefragt",
				WIDGET_IS_LOADING: 'Widget wird geladen...',
				RELOAD_SURE: "Durch diesen Vorgang werden Sie aus der aktuellen Sitzung ausgeloggt.### Möchten Sie ARSnova neu herunterladen?",
				RELOAD_GUEST_ADDITION: " Da Sie als Gast angemeldet sind, haben Sie nach dieser Aktion keinen Zugriff auf Ihre erstellten Sessions. Bitte stellen Sie sicher, dass alle benötigten Daten mit der Export-Funktion gesichert wurden.",
				OPEN_SESSIONS: "Sessions: offen",
				ACTIVE_SESSIONS: "Sessions: aktiv",
				CLOSED_SESSIONS: "Sessions: geschlossen",
				STUDENTS_USE_CASES: "Für Studenten",
				TEACHERS_USE_CASES: "Für Dozenten",

				/* diagnosis */
				DIAGNOSIS: "System",
				BROWSER_INFO: "Browser-Informationen",
				ARSNOVA_INFO: "ARSnova-Version",
				ARSNOVA_RELOAD: "ARSnova neu laden",
				VOTINGS: "Abstimmungen",
				SESSION_OWNERS: "Rolle Dozent/in",
				LEARNING_PROGRESS: "Lernstandsberechnung",
				PEER_INSTRUCTION_QUESTIONS: "2-Runden-Abstimmungen",
				ACTIVE_STUDENT_USERS: "Rolle Student/in",
				FEATURES: "Funktionsauswahl",
				ACTIVATE_FEATURES: "Hauptfunktionen",
				OPTIONAL_FEATURES: "Optionale Funktionen",
				SETTINGS_SAVED: 'Ihre Einstellungen wurden gespeichert',
				FEATURE_SAVE_ERROR: 'Es muss mindestens ein Feature ausgewählt werden',

				/* use cases */
				USECASES: "Use Cases",
				USECASES_CHOOSE: "Welche Frageformate und Funktionen brauchen Sie für Ihre Session?",
				USECASE_CLICKER: "Nur Quizfragen in den Formaten Multiple- und Single-Choice, Ja|Nein",
				USECASE_ABCD_CLICKER: "Nur die Publikumsfrage à la Günther Jauch: A|B|C|D ohne Fragetext",
				USECASE_PEER_GRADING: "Nur Evaluationsfragen mit 5-stufiger Likert-Skala und Auswertung",
				USECASE_FLASHCARD: "Nur Lernkarten fürs Selbststudium: Session als Lernkartei",
				USECASE_LIVE_FEEDBACK: "Nur Live Feedback (Verständnisbarometer)",
				USECASE_INTERPOSED_FEEDBACK: "Nur Zwischenfragen (Kummerkasten)",
				USECASE_ARSNOVA_TOTAL: "ARSnova total: alle Frageformate und alle Funktionen",
				USECASE_ARSNOVA_CUSTOM: "Eigene Auswahl",

				USECASES_CHOOSE_SHORT: "Welche Frageformate und Funktionen?",
				USECASE_CLICKER_SHORT: "Nur Quizfragen MC, SC, Ja|Nein",
				USECASE_ABCD_CLICKER_SHORT: "Nur die Publikumsfrage A|B|C|D",
				USECASE_PEER_GRADING_SHORT: "Nur Evaluationsfragen mit Auswertung",
				USECASE_FLASHCARD_SHORT: "Nur Lernkarten fürs Selbststudium",
				USECASE_LIVE_FEEDBACK_SHORT: "Nur Live Feedback",
				USECASE_INTERPOSED_FEEDBACK_SHORT: "Nur Zwischenfragen",
				USECASE_ARSNOVA_TOTAL_SHORT: "Alle Formate & Funktionen",
				USECASE_ARSNOVA_CUSTOM_SHORT: "Eigene Auswahl",

				USECASE_CLICKER_DETAILS: "###Quizfragen\n\n Nur die einfachen Frageformate:\n- Multiple-Choice (Mehrfachauswahl),\n- Single-Choice (Einfachauswahl) und\n- Ja|Nein (Entscheidungsfrage).\n\n ![SC-Frage](https://arsnova.thm.de/blog/wp-content/uploads/2016/02/SC-Frage-1.png \"600xautoxcenter\")",
				USECASE_ABCD_CLICKER_DETAILS: "###Publikumsfrage\n\n Wie bei Günther Jauch: nur A|B|C|D-Antwortoptionen ohne Fragetext. Keinerlei Aufwand für das Erstellen der Frage. Sie geben lediglich die Session-ID bekannt. Das Publikum wird automatisch auf die Abstimmseite geführt: ![Publikumsfrage](https://arsnova.thm.de/blog/wp-content/uploads/2015/12/ABCD-1-245x300.png \"245x300autoxcenter\") ",
				USECASE_PEER_GRADING_DETAILS: "###Evaluationsfragen\n\n Nur Fragen mit 5-stufiger [Likert-Skala](https://de.wikipedia.org/wiki/Likert-Skala) und Bewertungspunkten.",
				USECASE_FLASHCARD_DETAILS: "###Lernkarten fürs Selbststudium\n\n Vorderseite mit Frage, Rückseite mit Lösung. Sie können Videos und Bilder einbinden.",
				USECASE_LIVE_FEEDBACK_DETAILS: "###Live Feedback\n\n Falls nur ein \"Verständnisbarometer\" benötigt wird: Live Feedback zum Tempo und Verständnis der Vorlesung. Sie können die Abstimmung schließen und das aktuelle Ergebnis als Stimmungsbild festhalten. ![Live Feedback](https://arsnova.thm.de/blog/wp-content/uploads/2016/02/Live-Feedback.png \"245xautoxcenter\") ",
				USECASE_INTERPOSED_FEEDBACK_DETAILS: "###Zwischenfragen\n\n Falls nur ein digitaler \"Kummerkasten\" aufgestellt werden soll: Die Fragen der Studierenden sind anonym und nur sichtbar für die Lehrperson. ![Zwischenfrage](https://arsnova.thm.de/blog/wp-content/uploads/2016/02/Zwischenfrage.png \"245xautoxcenter\") ",
				USECASE_ARSNOVA_TOTAL_DETAILS: "###ARSnova total\n\n Alles, was ARSnova an Frageformaten und Unterstützungsfunktionen für die didaktischen Einsatz-Szenarien \"Peer Instruction\" und \"Inverted Classroom\" bietet, siehe die ARSnova-Broschüre [Feedback](https://arsnova.thm.de/blog/wp-content/uploads/2015/08/ARSnova-Produktprospekt-v5.pdf). ![Feedback](https://arsnova.thm.de/blog/wp-content/uploads/2013/07/ARSnova-Broschuere.png \"300xautoxcenter\") ",
				USECASE_ARSNOVA_CUSTOM_DETAILS: "###Mein ARSnova\n\n Sie können die Funktionalität Ihrer Session kombinieren aus: \n- Hörsaalfragen \n- Vorbereitungsaufgaben\n- Fragen der Studierenden\n- Live Feedback\n- 2-Runden-Abstimmungen\n- Lernstandsberechnung",

				/* errors */
				SESSION_NOT_FOUND: "Diese Session gibt es nicht",
				SESSION_LOCKED: "Die Session ist derzeit gesperrt",
				CONNECTION_PROBLEM: "Die Verbindung zum Server konnte nicht hergestellt werden",
				SESSION_ID_INVALID_LENGTH: "Der Zugangsschlüssel muss 8-stellig sein",
				SESSION_ID_INVALID: "Die Session-ID muss aus acht Ziffern bestehen",
				BROWSER_SESSION_EXPIRED: "Browser-Sitzung",
				BROWSER_SESSION_EXPIRED_MSG: "Ihre Browser-Sitzung ist abgelaufen. Möchten Sie ARSnova neu starten?",
				QUESTION_COULD_NOT_BE_SAVED: "Das Speichern der Frage war leider nicht erfolgreich",
				SETTINGS_COULD_NOT_BE_SAVED: "Das Speichern der Einstellungen war leider nicht erfolgreich",
				FEATURE_SETTINGS_COULD_NOT_BE_SAVED: "Das Speichern der Features war leider nicht möglich. Bitte ändern Sie die Features unter 'System' -> 'Features aktivieren'",
				URL_COULD_NOT_BE_FRAMED: "Der Hyperlink wird in einem neuen Browserfenster geöffnet...",

				/* misc */
				NEW_VERSION_TITLE: "Neue Version",
				NEW_VERSION_AVAILABLE: "Eine neue Version von ARSnova ist verfügbar. Möchten Sie aktualisieren?",
				PRESENTER: "Presenter",
				SESSION_ID: "Session",
				OF: "von",

				/* session import */
				IMP_BUTTON_IMPORT: "Import",
				IMP_LOADMSK: "Importiere sessions",
				IMP_ERROR: "Fehler bei Session-Import",
				IMP_ERROR_FORMAT: "JSON-Datei ist falsch formatiert",
				IMP_ERROR_SAVE: "Session konnte nicht gespeichert werden",
				IMP_ERROR_IMAGE: "Session konnte nicht gespeichert werden. Bild überschreitet maximale Größe.",

				/* CSV export*/
				QUESTIONS_CSV_EXPORT_BUTTON: "Fragen<br>exportieren",
				QUESTIONS_CSV_EXPORT_MSBOX_TITLE: "Fragen exportieren",
				QUESTIONS_CSV_EXPORT_MSBOX_INFO: "Die Fragen werden als CSV-Datei exportiert",

				/* CSV import*/
				QUESTIONS_CSV_IMPORT_BUTTON: "Fragen<br>importieren",
				QUESTIONS_CSV_IMPORT_MSBOX_TITLE: "Fragen importieren",
				QUESTIONS_CSV_IMPORT_ERR_IN_ROW: "in Zeile",
				QUESTIONS_CSV_IMPORT_TYPE_ERROR: "Ungültiger Fragentyp",
				QUESTIONS_CSV_IMPORT_ABSTENTION_ERROR: "Fehler im Feld 'abstention'",
				QUESTIONS_CSV_IMPORT_INVALID_FORMAT: "Ungültiges Dateiformat"
			};
			break;

		case 'en':
			/* falls through */
		default:
			moment.locale('en');
			Messages = {
				PRIVACY_MODE_WARNING_TITLE: "Privacy mode",
				PRIVACY_MODE_WARNING_TEXT: "Unfortunately, ARSnova doesn´t work in privacy mode, since your browser denies to write to the application storage.\n Please deactivate privacy mode for the period of usage of ARSnova and reload the page. Your anonymity is guaranteed even when private browsing mode is disabled.",
				BROWSER_NOT_SUPPORTED_MESSAGE: "Some ARSnova features might not work as intended in your browser. We recommend using one of the following browsers: ###.",
				UPDATE_BROWSER_MESSAGE: "Please update your ### browser in order to use ARSnova.",
				SESSION_IS_CLOSED: "Session \"###\" is currently closed.",
				FEATURE_COMING_SOON: "This feature will be available soon.",

				/* rolePanel */
				BLOG: "Blog",
				STUDENT: "Student",
				SPEAKER: "Teacher",
				TITLE_ROLE: "Feedback & Interaction",
				/* loginPanel */
				GUEST: "Guest",
				CHANGE_ROLE: "Change role",
				NO_GUEST_SPEAKER: "Note: You have to log in to create a session.",
				CONFIRM_GUEST_SPEAKER: "If you login as guest, you can manage newly created ARSnova sessions only from this device. Still login as guest?",
				GUEST_LOGIN: "Guest login",
				BACK_TO_ROLEPANEL: "Role",

				/* homePanel */
				LOGOUT: "Log out",
				LOGOUT_REQUEST: "Do you really want to logout?",
				SESSIONID_PLACEHOLDER: "Enter session ID  (8 digits)",
				ENTER_SESSIONID: "Insert session ID:",
				GO: "Enter session",
				LOAD_MORE: "Load more",
				YOUR_COURSE_SESSIONS: "Choose from your Moodle courses",
				LAST_VISITED_SESSIONS_STUDENT: "Visited sessions",
				LAST_VISITED_SESSIONS_SPEAKER: "Visited sessions as student",
				LEGEND: "Color and badge legend",
				OPEN_SESSION: "Open session",
				CLOSED_SESSION: "Closed session",
				CONFIRM_CLOSE_SESSION: "Are you sure you want to lock access to this session?",
				CONFIRM_CLOSE_SESSION_MESSAGE: "If you lock access, only students currently online will be able to participate.",
				ON_SESSION_CREATION_1: "The access key «###» to your session has been generated. You can see it anytime in the session overview. Please give this key to your students.",
				ON_SESSION_CREATION_2: "You can manage this session only in the role of lecturer via ###",
				ON_THIS_DEVICE: "on this device",
				DEMO_SESSION: "Demo session: ",

				/* LOAD MASK */
				LOAD_MASK: "Loading...",
				LOAD_MASK_LOGIN: "Login...",
				LOAD_MASK_SAVE: 'Saving...',
				LOAD_MASK_SEARCH: "Looking for sessions...",
				LOAD_MASK_SEARCH_QUESTIONS: "Looking for questions...",
				LOAD_MASK_SEARCH_COURSES: "Looking for courses...",
				LOAD_MASK_SESSION_DELETE: "Deleting session data...",
				LOAD_MASK_ACTIVATION: "Releasing question...",
				LOAD_MASK_SESSION_EXPORT: "Exporting session data...",
				LOAD_MASK_SESSION_IMPORT: "Importing session data...",
				LOAD_MASK_SESSION_PP_CLONE: "Copy public pool session...",
				LOAD_MASK_QUESTION_IMPORT: "Importing questions...",

				/* mySessionsPanel */
				HOME: "Start",
				SESSION: "Session",
				SESSION_INFO_TITLE: "Session information",
				SESSION_INFO_TITLE_SHORT: "Infos",
				NEW_SESSION: "New session",
				MY_SESSIONS: "My sessions",
				MY_PUBLIC_POOL_SESSIONS: "My pool sessions",
				SESSIONS: "Sessions",
				SESSIONID_WILL_BE_CREATED: "Session ID is being created...",
				SESSION_NAME: "Long Name",
				SESSION_NAME_PLACEHOLDER: "max. 50 digits",
				SESSION_SHORT_NAME: "Short name",
				SESSION_SHORT_NAME_PLACEHOLDER: "max. 8 digits",
				SESSION_SAVE: "Create Session",
				SESSION_OPTIONAL_INFO: "Information about session",
				SAVE: 'Save',

				/* MESSAGE OF THE DAY */
				MESSAGEOFTHEDAY: "\"Message of the Day\"",
				MESSAGEOFTHEDAY_BUTTON:	"Message of the Day",
				CREATE_NEW_MOTD: "Create new message",
				MY_MESSAGES: "Back",
				NEW_MOTD: "New message",
				SAVE_NEW_MESSAGE: "Save",
				EDIT_MOTD: "Edit message",
				DELETE_MESSAGE: "Delete message",
				MOTD_MANAGEMENT: "Manage messages",
				MOTD_TITLE: "Title",
				MOTD_TEXT: "Message",
				MOTD_AUDIENCE: "Taget group",
				MOTD_AUDIENCE_CHOOSE: "Choose target group",
				MOTD_AUDIENCE_ALL: "All",
				MOTD_AUDIENCE_LOGGEDIN: "All logged-in users",
				MOTD_AUDIENCE_TUTORS: "Teachers",
				MOTD_AUDIENCE_STUDENTS: "Students",
				MOTD_AUDIENCE_SESSION: "Session",
				MOTD_STARTDATE: "Start time",
				MOTD_ENDDATE: "End time",
				MOTD_NOTIFICATION_TITLE: "No title given",
				MOTD_NOTIFICATION_TEXT: "No text given",
				MOTD_NOTIFICATION_STARTDATE: "No start time given",
				MOTD_NOTIFICATION_ENDDATE: "No end time given",

				/* feedback */
				ABCD_TITLE: "A|B|C|D",
				FEEDBACK: "Feedback",
				MY_FEEDBACK: "My feedback",
				RESET_FEEDBACK: 'Reset feedback',
				FEEDBACK_GOOD: "Faster, please!",
				FEEDBACK_OKAY: "I can follow you.",
				FEEDBACK_BAD: "Slower, please!",
				FEEDBACK_NONE: "You've lost me.",
				FEEDBACK_VOTE: "Feedback",
				FEEDBACK_RESET: 'Your feedback has been reset',
				QUESTION_TO_SPEAKER: 'Feedback',
				QUESTION_INSTRUCTION: 'You are asking this question anonymously.',
				QUESTION_TEXT: "Question",
				QUESTION_TEXT_PLACEHOLDER: "Only the teacher can see your question. As soon as the teacher has seen your question, it is displayed in grey color. Answers to your questions can not be given in ARSnova.",
				QUESTION_SUBJECT: "Subject",
				QUESTION_SUBJECT_PLACEHOLDER: "max. 50 characters",
				QUESTION_SAVED: 'Your question has been saved.',
				NOTIFICATION: "Notice",
				TRANSMISSION_ERROR: "The question's transmission was unsuccessful.",
				QUESTION_CREATION_ERROR: "Failed in creating the question.",
				QUESTION_EDIT_ERROR: "Failed in editing the question.",
				ANSWER_CREATION_ERROR: "Your answer could not be saved.",
				RELEASE_VOTE_ERROR: "Failed releasing the vote.",
				SEND: "Send",

				/* questions */
				QUESTION: "Question",
				QUESTION_PLACEHOLDER: "Enter question",
				QUESTIONTEXT_PLACEHOLDER: "Enter question",
				QUESTION_MANAGEMENT: "Question Management",
				QUESTIONS: "Questions",
				TASKS: "Tasks",
				QUESTION_DETAILS: "Full text",
				QUESTION_DATE: "Date",
				DELETE: "Delete",
				EDIT: "Edit",
				CANCEL: "Cancel",
				DURATION: "Duration",
				SUBMIT_ANSWER: "Submit answer?",
				NO_QUESTIONS: "No questions found.",
				NO_UNLOCKED_QUESTIONS: "There are prepared questions, but these are currently not unlocked by your teacher.",
				LOADING_NEW_QUESTIONS: "Loading new questions.",
				NO_DATE: "No date",
				NO_SUBJECT: "No subject",
				SESSION_CLOSE_NOTICE: 'In order to prevent multiple votings, your teacher has closed the session. Please log out at the end of the lecture!',
				NOTICE_READ: "I understood it",
				STATUS: "Status",
				FREETEXT_ANSWER_TEXT: "My Answer",
				FREETEXT_DETAIL_HEADER: "Answer",
				FREETEXT_DETAIL_ANSWER: "Answer",
				FORMAT_PLACEHOLDER: "(use Markdown for text formatting and LaTeX for mathematical formulas)",
				NO_ANSWERS: "No answers found.",
				ONLY_ABSTENTION_ANSWERS: "There are ###, but no answers yet.",
				FREETEXT_DETAIL_LABEL: "There ### and %%%:",
				ANSWER_SAVED: 'Your answer has been saved.',
				MISSING_INPUT: "Please fill out all required fields.",
				SHOWCASE: "Showcase",
				LEAVE: "Leave",
				MEMBERS_ONLY: "This question is visible to course members only.",
				QUESTION_RATING: "Likert-type Scale",
				QUESTION_RATING_SHORT: "Rating",
				QUESTION_GRADE: "Grading",
				QUESTION_GRADE_SHORT: "Grade",
				QUESTION_GRID: "Picture Question (Hot spots)",
				QUESTION_GRID_SHORT: "Picture",
				QUESTION_MC: "Multiple Choice: Select",
				QUESTION_MC_SHORT: "MC",
				QUESTION_YESNO: "Polar Question",
				QUESTION_LIVE_CLICKER: "Live Clicker",
				QUESTION_YESNO_SHORT: "Yes | No",
				QUESTION_SINGLE_CHOICE: "Single Choice: Choose",
				QUESTION_SINGLE_CHOICE_SHORT: "Single",
				QUESTION_FREETEXT: "Open-ended Question",
				QUESTION_FREETEXT_SHORT: "Free Text",
				OPEN_QUESTION: "Open question",
				CLOSED_QUESTION: "Closed question",
				CLOSED_VOTING: "Voting closed",
				CONFIRM_CLOSE_VOTE: "Are you sure you want to close the voting?",
				CONFIRM_CLOSE_ALL_VOTES: "Are you sure you want to close the voting?",
				CONFIRM_CLOSE_QUESTION: "Are you sure you want to close this question?",
				CONFIRM_CLOSE_ALL_QUESTIONS: "Are you sure you want to close all questions?",
				CONFIRM_CLOSE_QUESTION_MESSAGE: "If you close this question, students will not be able to view or answer this question.",
				CONFIRM_CLOSE_VOTE_MESSAGE: "If you close the voting, students will not be able to answer this question.",
				CONFIRM_CLOSE_ALL_VOTES_MESSAGE: "If you close the voting for all questions, students will not be able to answer any questions.",
				CONFIRM_CLOSE_ALL_QUESTIONS_MESSAGE: "If you close all questions, students will not be able to view or answer any questions.",
				CONFIRM_ANSWERS_CHANGED: "This will reset all current answers.",
				QUESTION_PREVIEW_BUTTON_TITLE: "Preview",
				QUESTION_PREVIEW_BUTTON_TITLE_DESKTOP: "Smartphone preview 360x640",
				QUESTION_PREVIEW_DIALOGBOX_TITLE: "Question preview",
				QUESTION_PREVIEW_DIALOGBOX_BUTTON_TITLE: "Close preview",
				ANSWER_PREVIEW_BUTTON_TITLE: "Preview",
				ANSWER_PREVIEW_DIALOGBOX_TITLE: "Preview answers",
				ANSWER_PREVIEW_DIALOGBOX_BUTTON_TITLE: "OK",
				ANSWER_POINTS: "Answer points",
				ANSWER_POINTS_CORRECT: "Correct",
				ANSWER_POINTS_INCORRECT: "Incorrect",
				NO_ANSWER_MARKED_CORRECT_MESSAGE: "You have not marked any answer option as correct.",
				NO_ANSWER_MARKED_CORRECT_OPTION_YES: "Save anyway",
				NO_ANSWER_MARKED_CORRECT_OPTION_NO: "Abort",
				ACTIVE_QUESTION_CLOSED: "The active question has been locked",
				ACTIVE_QUESTION_VOTING_CLOSED: "Voting for the active question has been closed",
				SESSION_PREVIEW_BUTTON_TITLE_DESKTOP: 'Description preview 320x640',
				HINT_FOR_SOLUTION: "Hint for solution",
				HINT_FOR_SOLUTION_EDIT: "Hint for solution?",
				SAMPLE_SOLUTION: "Sample solution",

				/* sort */
				SORT_QUESTIONS_TITLE: "Sort Questions",
				SORT_CATEGORIES_TITLE: "Sort Categories",
				SORT_CATEGORIES: "Categories",
				SORT_SAVED: "Your sort order has been saved.",
				SORT_SAVE_AND_CONTINUE: "Save and continue",
				SORT_TRANSMISSION_ERROR: "Sort failed.",

				/* user */
				QUESTIONS_TO_STUDENTS: "Teacher's questions",
				QUESTIONS_FROM_STUDENTS: "Students' questions",
				UNREAD_QUESTIONS_FROM_STUDENTS: "Unread questions",
				PREPARATION_QUESTIONS: "Prep tasks",
				PREPARATION_QUESTIONS_LONG: "Preparation tasks",
				PREPARATION_QUESTION_SHORT: "Prep task",
				PREPARATION_QUESTION_LONG: "Preparation task",
				QUESTION_REQUEST: "I've got a question",
				LECTURE_QUESTIONS: "Lecture",
				LECTURE_QUESTION_LONG: "Lecture question",
				LECTURE_QUESTIONS_LONG: "Lecture questions",
				FLASHCARD_SHORT: "FC",
				FLASHCARDS: "Flashcards",
				FLASHCARD: "Flashcard",
				MASK_ALREADY_ANSWERED: "You have already voted",
				MASK_IS_ABSTENTION_ANSWER: "You´ve abstained from answering",
				MASK_CORRECT_ANSWER_IS: "The correct answer is...",
				MASK_VOTE_CLOSED: "Voting not enabled",
				ONE_NEW_LECTURE_QUESTION: '1 new lecture question',
				ONE_NEW_PREPARATION_QUESTION: '1 new preparation task',
				SEVERAL_NEW_LECTURE_QUESTIONS: '### new lecture questions',
				SEVERAL_NEW_PREPARATION_QUESTIONS: '### new preparation tasks',
				WANNA_ANSWER: 'Would you like to answer now?',
				THERE_ARE: "There are",
				NEW_QUESTIONS: "new questions.",
				MY_QUESTIONS: "My questions",
				MY_LEARNING_PROGRESS: "My progress",
				VERSUS: "vs",
				LEARN: "Learn",
				LEARN_WITH_SELECTION: "Learn with selection",
				UNANSWERED_QUESTIONS: "Open Questions",
				PREPARATION: "Preparation",
				LECTURE: "Lecture",
				RESET_ALL_ANSWERS: "Reset all answers",
				SHOW_FLASHCARD_ANSWER: "Show answer",
				HIDE_FLASHCARD_ANSWER: "Hide answer",
				COMPRESSING_MASK: "Your image will be compressed ...",
				IMAGE_NEEDED: "You are supposed to upload a picture.",
				PICTURE_RIGHT_INFORMATION: ['Please note, that you cannot use pictures for which you do not have the right to use (copyright law) or which contain pornographic or violent, racial or discriminating (§130 StGB) content!\n',
					'Submit answer?'
				].join('\n'),

				/* speaker */
				LIVE_FEEDBACK: "Instant feedback",
				COURSES_LEARNING_PROGRESS: "Class progress",
				COURSES_LEARNING_PROGRESS_SHORT: "Class progress",
				CURRENT_VALUE: "Current value",
				HOW_TO_CALCULATE_LEARNING_PROGRESS: "How to calculate the learning progress?",
				QUESTION_BASED_PROGRESS: "Question based",
				SCORE_BASED_PROGRESS: "Score based",
				WHICH_QUESTIONS_TO_USE_FOR_LEARNING_PROGRESS: "Which questions should be used for the calculation?",
				BOTH: "Both",
				QUESTION_BASED_PROGRESS_EXPLANATION: [
					'With the question-based learning progress, all questions are weighted equally even if they have a different maximum value. For example, the progress is calculated as follows:\n',
					'There are 3 questions which have a maximum value of 10, 20, and 30.',
					'A question is treated as corretly answered if their respective maximum value is scored.',
					'If an incorrect answer option is chosen, negative points are scored and the maximum value cannot be reached anymore.',
					'If a student scores 10, 20, and 20 points, this will mean the last question was not answered correctly.',
					'The individual learning progress is calculated using this formula: \\\\[ l_{\\text{S}} = \\frac{\\text{Correct answers}}{\\text{Questions}} = \\frac{2}{3} \\hat{=}\\, 67\\%\\\\]\n',
					'For the whole course, the progress is calculated using the total number of students: \\\\[l_{\\text{C}} = \\frac{\\text{Correct answers}}{\\text{Questions} \\cdot \\text{Students}}\\\\]'
				].join('\n'),
				SCORE_BASED_PROGRESS_EXPLANATION: [
					'The score-based learning progress puts more weight on questions with many correct answer options compared to questions with only one correct option. For example, the learning progress is calculated as follows:\n',
					'There are 3 questions which have a maximum value of 10, 20, and 30.',
					'This means that students can score a total of 60 points for all three questions.',
					'If an incorrect answer option is chosen, the score will be reduced, e.g., to 30.',
					'The individual learning progress is calculated using this formula: \\\\[ l_{\\text{S}} = \\frac{\\text{Points scored}}{\\text{Points achievable}} = \\frac{30}{60} \\hat{=}\\, 50\\%\\\\]\n',
					'For the whole course, the progress is calculated using the total number of students: \\\\[l_{\\text{C}} = \\frac{\\text{Points scored by all students}}{\\text{Points achievable} \\cdot \\text{Students}}\\\\]'
				].join('\n'),
				QUESTIONS_ABBR: "Qs",
				POINTS_ABBR: "Pts",
				NEW_LECTURE_QUESTION: "New lecture question",
				NEW_PREPARATION_QUESTION: "New preparation task",
				NEW_QUESTION_TITLE: "Question",
				ARE_YOU_SURE: "Are you sure?",
				DELETE_QUESTION_TITLE: "Delete question",
				DELETE_QUESTIONS_TITLE: "Delete questions",
				DELETE_SESSION_TITLE: "Delete session",
				DELETE_SESSION_NOTICE: "All questions and answers of this session will be deleted.",
				CATEGORY: "Subject",
				CATEGORY_PLACEHOLDER: "Enter subject",
				ABSTENTION: 'Abstention',
				ABSTENTIONS: 'Abstentions',
				ABSTENTION_POSSIBLE: 'Abstention possible?',
				MY_COURSES: "My courses:",
				COULD_NOT_SEARCH: "Could not search courses.",
				CORRECT_ANSWER: 'Which option is supposed to be right?',
				YES: "Yes",
				NO: "No",
				NONE: "None",
				CONTINUE: 'Continue',
				ANSWERS: "Answers",
				ANSWERS_SHOWN: "x shown",
				ANSWER_OPTIONS: "Answer options",
				ANSWERS_STATISTICS: "Answer statistics",
				ENTER_ANSWER_OPTION: "Enter option",
				ANSWERS_PER_QUESTION: "Answers per question",
				ANSWER: "Answer",
				COUNT: "Count",
				CORRECT: "Correct",
				CORRECT_PLACEHOLDER: "Correct answer",
				WRONG: "Wrong",
				WRONG_PLACEHOLDER: "Wrong answer",
				OPTION_PLACEHOLDER: "Option",
				STATISTIC: "Statistics",
				STATISTICS: "Statistics",
				ALL_CORRECT: "All correct",
				ALL_WRONG: "All wrong",
				LEARNING_STATUS: "Learning status of the course",
				DELETE_ALL: "Delete all",
				DELETE_ANSWERS_REQUEST: "Delete answers?",
				DELETE_ALL_ANSWERS_REQUEST: "Delete all answers?",
				DELETE_ROUND_ANSWERS_COMPLETED: "All answers of the actual round have been deleted.",
				RELEASE_LIVE_VOTING: "Release voting",
				CLOSE_LIVE_VOTING: "Freeze voting",
				QUESTION_REMAINS: "The question itself stays unaffected.",
				INCOMPLETE_INPUTS: "Your inputs are incomplete.",
				ALL_QUESTIONS_REMAIN: "The questions themselves stay unaffected.",
				DELETE_ALL_ANSWERS_INFO: "This will also delete all previously given answers.",
				CHANGE_RELEASE: "Changing the release...",
				TYPE: 'Type',
				INFINITE: "infinite",
				MINUTE: "Minute",
				MINUTES: "Minutes",
				SECONDS: "Seconds",
				BACK: "Back",
				FLASHCARD_FRONT_PAGE: 'Front side',
				FLASHCARD_BACK_PAGE: 'Back side',
				SAVE_AND_CONTINUE: "Save and ask a new question",
				PICTURE_MAX_FILESIZE: "Maximum file size: ###",
				SELECT_PICTURE_FS: "URL",
				SELECT_PICTURE_URL: "Picture URL",
				SELECT_PICTURE_URL_SHORT: "URL",
				REMOVE_PICTURE: "Remove picture",
				CHOOSE_PICTURE: "Choose image",
				SEARCH_PICTURE: "Upload pic",
				SEARCH_PICTURE_SHORT: "Upload",
				PICTURE_SOURCE: "",
				GRID_LOADING: "Loading",
				GRID_LOAD: "Load",
				GRID_ERROR_URL_MISSING: "Please insert a valid url.",
				GRID_ERROR_IMAGE_NOT_LOADED: "The image could not be loaded.",
				GRID_ERROR_FILE_SIZE: "The used image (%%%) exceeds the maximum file size (###).",
				GRID_LABEL_ZOOM: "Zoom (in percent)",
				GRID_LABEL_SQUARES: "Squares per edge",
				GRID_LABEL_FIELD_X: "x-axis",
				GRID_LABEL_FIELD_Y: "y-axis",
				GRID_LABEL_HEATMAP: "Heatmap",
				GRID_LABEL_HEATMAP_SHORT: "HM",
				GRID_LABEL_SHOW_PERCENT: "Show number of marked spots",
				GRID_LABEL_INVERT_GRIDCOLORS: "Invert grid colors",
				GRID_LABEL_CV_TRANSPARENCY: "color background",
				GRID_LABEL_ABSOLUTE: 'absolute (#)',
				GRID_LABEL_RELATIVE: 'percentage (%)',
				GRID_LABEL_ABSOLUTE_SHORT: '#',
				GRID_LABEL_RELATIVE_SHORT: '%',
				GRID_LABEL_NONE_SHORT: 'w/o',
				GRID_LABEL_NONE: 'hidden',
				GRID_LABEL_MARK_TOGGLE_ANSWERS: "Deselect number of checked answers",
				GRID_LABEL_THRESHOLD_CORRECT_ANSWERS: "Value of correct answers ",
				GRID_ERROR_LOADING_IMAGE_FS: 'Could not load image from file system',
				GRID_CONFIG_IMAGE: "Image configuration",
				GRID_CONFIG_GRID: "Grid configuration",
				GRID_LABEL_REMAINING_DOTS: "Remaining points for marking: ",
				GRID_LABEL_NUMBER_OF_DOTS: "Points for marking",
				GRID_LABEL_DELETE_MODERATION: "Remove template",
				ERROR: 'Notice',
				CORRECT_ANSWERS: "Correct answers",
				SETTINGS: "Settings",
				SETTINGS_HINT_TEXT: "Hint <br>Maximal filesize is 150 KB.",
				TEMPLATE_FOR_MODERATION: "Templates for an opinion poll",
				TEMPLATE: "Template",
				APPLY: "Apply",
				MISSING_INPUTS: "Some inputs are incomplete:",
				MISSING_SUBJECT: "The subject is missing",
				MISSING_QUESTION: "The question is missing",
				MISSING_ANSWERS: "Some answer options are missing",
				MISSING_IMAGE: "No picture has been uploaded",
				MISSING_FLASHCARD: "The back page text is missing",

				/*Export session*/
				EXPORT_MSG: "What should be exported?",
				EXPORT_SESSION_TITLE: "Session Export",
				EXPORT_BUTTON_LABEL: "Export",
				EXPORT_SESSION_TO_PUBLIC_TITLE: "Public Pool Export",
				EXPORT_FIELD_NAME: "Name of teacher",
				EXPORT_FIELD_UNI: "University",
				EXPORT_FIELD_LOGO: "Logo",
				EXPORT_FIELD_SUBJECT: "Course of studies",
				EXPORT_FIELD_LICENCE: "License",
				EXPORT_FIELD_LEVEL: "Level",
				EXPORT_FIELD_EMAIL: "Email",
				EXPORT_FIELD_SPECIAL_FIELD: "Faculty",
				EXPORT_SELECTED_SESSIONS_TITLE: "Export sessions",
				EXPORT_SELECTED_SESSIONS_MSG: "Where should the session(s) be exported?",
				EXPORT_SESSION_INFORMATION: "Auditorium questions and preparation tasks questions for the selected sessions will be exported.",
				EXPORT_NOTIFICATION:	"No session selected.",
				EXPORT_IOS_NOTIFICATION: "An export can not be performed on iOS devices.",
				EXPORT_BUTTON_FS: "My System",
				EXPORT_BUTTON_PP: "Public Pool",
				EXPORT_PP_NOTIFICATION: 'As a "guest" you can not export a session in the public pool. Please log in using one of the other approaches.',
				EXPORT_SESSION_LABEL: 'Selection of sessions to be exported:',

				/*Import session*/
				IMPORT_IOS_NOTIFICATION: "An import can not be performed on iOS devices.",
				IMPORT_NOT_SUPPORTED: "Session Import is not supported for your browser.",

				/*Round management*/
				POLL_MANAGEMENT: "Vote",
				ROUND_MANAGEMENT: "Round Management",
				START_FIRST_ROUND: "Start round 1",
				START_SECOND_ROUND: "Start round 2",
				CANCEL_DELAYED_ROUND: "Modify settings",
				END_ROUND_IMMEDIATELY: "Close round immediately",
				END_VOTE_IMMEDIATELY: "Close voting immediately",
				END_ROUND: "Close voting round",
				END_ROUND_WARNING: "If the current voting round is closed, no more polls will be possible until a new round has started or the question is unlocked manually. Would you like to continue?",
				RESET_ROUND: "Reset vote",
				RESET_ROUND_WARNING: "All answers of all rounds will be reset. Would you like to continue?",
				RESET_ROUND_COMPLETED: "Vote reset completed.",
				ONE_NEW_DELAYED_QUESTION: 'New time-limited question',
				ONE_NEW_DELAYED_QUESTION_ROUND1: 'There is one new time-limited question.',
				ONE_NEW_DELAYED_QUESTION_ROUND2: 'A question has been released for the second round of voting.',
				VOTING_CLOSED: "The voting has ended.",
				VOTING_OPENED: "The voting has started.",
				START_VOTING: "Start voting",
				FIRST_ROUND: "Round 1",
				SECOND_ROUND: "Round 2",
				BOTH_ROUNDS: "Round 1|2",

				/*Markdown Editor*/
				EDITOR_VIMEO: "Vimeo",
				EDITOR_YOUTUBE: "Youtube",
				EDITOR_HYPERLINK: "Hyperlink",
				EDITOR_PICTURE: "Picture",
				EDITOR_URL: "Reference",
				EDITOR_TITLE: "Text",
				EDITOR_URL_PLACEHOLDER: "https://",
				EDITOR_TITLE_PLACEHOLDER: "visible text",
				EDITOR_EXTENDED_OPTIONS: "Further options",
				EDITOR_IMAGE_POSITION: "Position",
				EDITOR_IMAGE_HEIGHT_LABEL: "Max. height (pixel)",
				EDITOR_IMAGE_WIDTH_LABEL: "Max. width (pixel)",
				EDITOR_CENTER: "center",
				EDITOR_RIGHT: "right",
				EDITOR_LEFT: "left",

				EDITOR_BOLD_TOOLTIP: "Bold",
				EDITOR_HEADER_TOOLTIP: "Header",
				EDITOR_HYPERLINK_TOOLTIP: "Hyperlink",
				EDITOR_ULIST_TOOLTIP: "Unsorted list",
				EDITOR_OLIST_TOOLTIP: "Sorted list",
				EDITOR_LATEX_TOOLTIP: "Latex",
				EDITOR_CODE_TOOLTIP: "Code",
				EDITOR_QUOTE_TOOLTIP: "Quote",
				EDITOR_YOUTUBE_TOOLTIP: "Youtube",
				EDITOR_VIMEO_TOOLTIP: "Vimeo",
				EDITOR_PICTURE_TOOLTIP: "Picture",
				EDITOR_INFO_TOOLTIP: "Info",

				EDITOR_INFO_HINT: "You can markup text inside of ARSnova by using [Markdown](https://en.wikipedia.org/wiki/Markdown). The most frequent used Markdown options are accessible above all supported textareas. ARSnova also supports [GitHub Flavored Markdown](https://github.com/adam-p/markdown-here/wiki/Markdown-Cheatsheet).",

				/*Public pool*/
				SESSIONPOOL_LEVEL: "Level",
				SESSIONPOOL_CLONE: "Copy",
				SESSIONPOOL_AUTHORINFO: "Author information",
				SESSIONPOOL_SESSIONINFO: "Public Session information",
				SESSIONPOOL_LOGOINFO: "Logo",
				SESSIONPOOL_INFO: "Description",
				SESSIONPOOL_COUNT_QUESTION: "Number of isssues",
				SESSIONPOOL_NOTIFICATION_EMAIL: "Email format is invalid",
				SESSIONPOOL_NOTIFICATION_LICENCE: "Invalid license",
				SESSIONPOOL_NOTIFICATION_SUBJECT: "Invalid subject",
				SESSIONPOOL_NOTIFICATION_NAME:	"Name must be entered",
				SESSIONPOOL_NOTIFICATION_UNIVERSITY: "University must be stated",
				SESSIONPOOL_NOTIFICATION_SESSION_NAME:	"Session name must be stated",
				SESSIONPOOL_NOTIFICATION_SESSION_SHORTNAME:	"Session short name must be stated",
				SESSIONPOOL_NOTIFICATION_QUESTION_NUMBER: "Session must contain at least one question",
				SESSIONPOOL_NOTIFICATION:	"Entries are not complete",
				SESSIONPOOL_ERR_GET_NOTFOUND: "Could not find session.",
				SESSIONPOOL_ERR_CAT_NOTFOUND: "No sessions available for this category.",
				SESSIONPOOL_ERR_NO_PPSESSIONS: "No public pool sessions found.",
				SESSIONPOOL_ERR_PPSESSION_RIGHTS: "You are not authorized to see public pool sessions.",
				SESSIONPOOL_ERR_GET_SESSION: "You are not authorized to see this session.",
				SESSIONPOOL_TITLE: "Session Pool",
				SESSIONPOOL_VISIT:	"Visit",
				SESSIONPOOL_CHARACTERS:	'characters',
				SESSIONPOOL_INFOS:	'Infos',

				/* question types */
				EVALUATION: "+|-",
				SCHOOL: "A-F",
				MC: "MC",
				YESNO: "Y|N",
				ABCD: "SC",
				GRID: "Pic",
				FREETEXT: "Text",
				MC_LONG: "Multiple Choice",
				ABCD_LONG: "Single Choice",
				EVALUATION_LONG: "Rating",
				EVALUATION_ALT: "Evaluation",
				EVALUATION_QUESTIONS: "Rating questions",
				SCHOOL_LONG: 'Grade',
				YESNO_LONG: 'Yes|No',
				GRID_LONG: "Hot Spots",
				FREETEXT_LONG: 'Free Text',
				BUZZWORD: "Buzzword for",
				BUZZWORD_A: "Buzzword for A",
				BUZZWORD_B: "Buzzword for B",
				BUZZWORD_C: "Buzzword for C",
				BUZZWORD_D: "Buzzword for D",
				SCHOOL_A: "excellent",
				SCHOOL_B: "good",
				SCHOOL_C: "average",
				SCHOOL_D: "poor",
				SCHOOL_E: "very poor",
				SCHOOL_F: "inadequate",
				SCHOOL_NONE: "abstention",
				EVALUATION_PLUSPLUS: "strongly agree",
				EVALUATION_PLUS: "agree",
				EVALUATION_NEUTRAL: "neutral",
				EVALUATION_MINUS: "disagree",
				EVALUATION_MINUSMINUS: "strongly disagree",
				IMAGE_QUESTION_LBL: "Upload image/photo as answer?",
				EXPECT_ANSWER_TEXT: "Allow adding text to picture?",

				IMAGE_QUESTION_MINIATUR_VIEW: "Grid",
				IMAGE_QUESTION_HORIZONTAL_VIEW: "Horizontal",
				IMAGE_QUESTION_VERTICAL_VIEW: "Vertical",

				/* action buttons - <br/> forces line break for consistent look */
				CREATE_NEW_SESSION: "Create new<br/>session",
				NEW_QUESTION: "Create new<br/>question",
				NEW_FLASHCARD: "Create new<br/>flashcard",
				NEW_TASK: "Create new<br/>task",
				SHOWCASE_MODE: "Present<br/>question",
				SHOWCASE_TASK: "Present<br/>task",
				SHOWCASE_MODE_PLURAL: "Present<br/>questions",
				SHOWCASE_TASKS: "Present<br/>tasks",
				SHOWCASE_FLASHCARD: "Present</br>flashcard",
				SHOWCASE_FLASHCARDS: "Present</br>flashcards",
				SHOWCASE_LIVE_CLICKER: "A|B|C|D</br>question",
				SHOW_STATISTIC: "Show<br/>statistics",
				RELEASE_STATISTIC: "Release<br/>statistics",
				RELEASE_QUESTION: "Release<br/>question",
				ACTIVATE_TIMER: "Activate<br/>timer",
				RELEASE_ALL_QUESTIONS: "Release<br/>questions",
				RELEASE_VOTE: "Release<br/>vote",
				RELEASE_ALL_VOTES: "Release<br/>all votes",
				STOP_QUESTION: "Lock<br/>question",
				STOP_ALL_QUESTIONS: "Lock<br/>questions",
				START_SESSION: "Open<br/>access",
				STOP_SESSION: "Lock<br/>access",
				MARK_CORRECT_ANSWER: "Mark<br/>correct",
				DELETE_QUESTION: "Delete<br/>question",
				DELETE_ALL_QUESTIONS: "Delete<br/>questions",
				DELETE_ANSWERS: "Delete<br/>answers",
				DELETE_SESSION: "Delete<br/>session",
				GIVE_FEEDBACK: "Give instant<br/>feedback",
				QUESTION_REQUEST_ADHOC: "I've got a<br/>question",
				GRID_LABEL_WEAKEN_IMAGE: "Transparent<br>image",
				GRID_LABEL_SHOW_HEATMAP: "Show<br>heatmap",
				RESET_QUESTION: "Reset<br>vote",
				READJUST_TIMER: "Readjust<br>timer",
				SWITCH_VOTING_MODE: "Two-round<br/>voting",
				SORT_QUESTIONS: "Sort<br/>questions",
				SORT_ALPHABET: "Alphabetic<br/>sort",
				SORT_TIME: "Time<br/>sort",
				SORT_RANDOM: "Random<br/>sort",
				SORT_REVERT: "Revert<br/>changes",
				CHANGE_FEATURES: "Change<br/>use case",
				CHANGE_ROLE_BUTTONTEXT: "Change<br/>role",

				/* about */
				MANUAL: "Manual",
				ABOUT: "About",
				IMPRINT: "Imprint",
				PRIVACY: "Privacy policy",

				OPINION: "Your opinion matters",
				WIDGET_IS_LOADING: 'Widget is loading...',
				RELOAD_SURE: "You will be logged out from the current session.### Do you want to reload ARSnova?",
				RELOAD_GUEST_ADDITION: " Since you are logged in as guest, you can not access your created sessions after this action. Please make sure that all the necessary data have been backed up with the export function.",
				OPEN_SESSIONS: "Sessions: open",
				ACTIVE_SESSIONS: "Sessions: active",
				CLOSED_SESSIONS: "Sessions: closed",
				STUDENTS_USE_CASES: "Student's Use Cases",
				TEACHERS_USE_CASES: "Teacher's Use Cases",

				/* diagnosis */
				DIAGNOSIS: "System",
				BROWSER_INFO: "Browser information",
				ARSNOVA_INFO: "ARSnova version",
				ARSNOVA_RELOAD: "Reload ARSnova",
				VOTINGS: "Votings",
				SESSION_OWNERS: "Users in a teacher's role",
				PEER_INSTRUCTION_QUESTIONS: "Two-round votings",
				ACTIVE_STUDENT_USERS: "Users in a student's role",
				LEARNING_PROGRESS: "Learning progress",
				FEATURES: "Selection of functions",
				ACTIVATE_FEATURES: "Main functions",
				OPTIONAL_FEATURES: "Optional functions",
				SETTINGS_SAVED: 'Your settings have been saved.',
				FEATURE_SAVE_ERROR: 'At least one feature must be selected.',

				/* use cases */
				USECASES: "Use Cases",
				USECASES_CHOOSE: "Which question types and functions do you want to offer in your session?",
				USECASE_CLICKER: "Clicker questions",
				USECASE_ABCD_CLICKER: "\"Ask the Audience\" (A|B|C|D single-choice question)",
				USECASE_PEER_GRADING: "Evaluation (5-level Likert scale)",
				USECASE_FLASHCARD: "Flashcards for self studies",
				USECASE_LIVE_FEEDBACK: "Instant Feedback",
				USECASE_INTERPOSED_FEEDBACK: "Questions from the audience",
				USECASE_ARSNOVA_TOTAL: "All-inclusive (all question types, all functions)",
				USECASE_ARSNOVA_CUSTOM: "My ARSnova",

				USECASES_CHOOSE_SHORT: "Select use case",
				USECASE_CLICKER_SHORT: "Clicker questions",
				USECASE_ABCD_CLICKER_SHORT: "Ask the Audience",
				USECASE_PEER_GRADING_SHORT: "Evaluation",
				USECASE_FLASHCARD_SHORT: "Flashcards",
				USECASE_LIVE_FEEDBACK_SHORT: "Live feedback",
				USECASE_INTERPOSED_FEEDBACK_SHORT: "Interposed Questions",
				USECASE_ARSNOVA_TOTAL_SHORT: "All-inclusive",
				USECASE_ARSNOVA_CUSTOM_SHORT: "My ARSnova",

				USECASE_CLICKER_DETAILS: "###Clicker Questions\n\n Only simple question types: Multiple Choice (select), Single Choice (choose), Yes|No (polar question), Likert Scale (evaluation), and Grading (school grades).",
				USECASE_ABCD_CLICKER_DETAILS: "###Ask the Audience\n\n Only A|B|C|D response options without question text as known from the quiz show \"Who Wants to Be a Millionaire\".",
				USECASE_PEER_GRADING_DETAILS: "###Evaluation Questions\n\n 5-level [Likert items](https://en.wikipedia.org/wiki/Likert_scale) with values in the range of -10 to 10. The response options are editable, default: strongly agree | agree | neutral | disagree | strongly disagree.",
				USECASE_FLASHCARD_DETAILS: "###Flashcards for private study\n\n Question on front side, answer on back side. You can embed videos and pictures.",
				USECASE_LIVE_FEEDBACK_DETAILS: "###Live Feedback\n\n With the use of \“Smileys\”, the listeners can indicate their pace of learning and understanding of the lecture.",
				USECASE_INTERPOSED_FEEDBACK_DETAILS: "###Interposed Questions\n\n The listeners can pose questions, without interrupting the class.",
				USECASE_ARSNOVA_TOTAL_DETAILS: "###All-inclusive ARSnova\n\n All didactic functions and question types that ARSnova supports for [Peer Instruction](https://en.wikipedia.org/wiki/Peer_instruction) and [Flipped Classroom](https://en.wikipedia.org/wiki/Flipped_classroom).",
				USECASE_ARSNOVA_CUSTOM_DETAILS: "###My ARSnova\n\n Personal selection of didactic functions...",


				/* errors */
				SESSION_NOT_FOUND: "This session does not seem to exist.",
				SESSION_LOCKED: "This session is currently locked.",
				CONNECTION_PROBLEM: "The connection to the server has failed.",
				SESSION_ID_INVALID_LENGTH: "The session ID has to be exactly 8 digits.",
				SESSION_ID_INVALID: "The session ID may only consist of 8 digits.",
				BROWSER_SESSION_EXPIRED: "Browser session expired",
				BROWSER_SESSION_EXPIRED_MSG: "Your current browser session is expired. Do you want to restart ARSnova?",
				QUESTION_COULD_NOT_BE_SAVED: "Could not save question",
				SETTINGS_COULD_NOT_BE_SAVED: "Could not save settings",
				FEATURE_SETTINGS_COULD_NOT_BE_SAVED: "Could not save feature settings. Please change these settings at 'System' -> 'Activate feature'.",
				URL_COULD_NOT_BE_FRAMED: "The selected hyperlink opens in a new browser window.",

				/* misc */
				NEW_VERSION_TITLE: "New Version",
				NEW_VERSION_AVAILABLE: "A new version of ARSnova is available. Do you want to update?",
				PRESENTER: "Presenter",
				SESSION_ID: "Session ID",
				OF: "of",

				/* session import */
				IMP_BUTTON_IMPORT: "Import",
				IMP_LOADMSK: "Importing sessions",
				IMP_ERROR: "Error while importing sessions",
				IMP_ERROR_FORMAT: "JSON file is not formated correctly",
				IMP_ERROR_SAVE: "Could not save session to database.",
				IMP_ERROR_IMAGE: "Could not save session, image exceeds maximal size.",

				/* CSV export */
				QUESTIONS_CSV_EXPORT_BUTTON: "Export<br>questions",
				QUESTIONS_CSV_EXPORT_MSBOX_TITLE: "Export Questions",
				QUESTIONS_CSV_EXPORT_MSBOX_INFO: "The questions will be exported as a CSV file.",

				/* CSV import */
				QUESTIONS_CSV_IMPORT_BUTTON: "Import<br>questions",
				QUESTIONS_CSV_IMPORT_MSBOX_TITLE: "Import questions",
				QUESTIONS_CSV_IMPORT_ERR_IN_ROW: "at line",
				QUESTIONS_CSV_IMPORT_TYPE_ERROR: "Invalid question type",
				QUESTIONS_CSV_IMPORT_ABSTENTION_ERROR: "Error in field 'abstention'",
				QUESTIONS_CSV_IMPORT_INVALID_FORMAT: "Invalid file format"
			};
			break;
	}
	// make Messages globally accessible
	exports.Messages = Messages;
})(window);
