/*
 * This file is part of ARSnova Mobile.
 * Copyright (C) 2011-2012 Christian Thomas Weber
 * Copyright (C) 2012-2016 The ARSnova Team
 *
 * ARSnova Mobile is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * ARSnova Mobile is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with ARSnova Mobile.  If not, see <http://www.gnu.org/licenses/>.
 */

Ext.define('ARSnova.view.AnswerPreviewBox', {
	extend: 'Ext.MessageBox',

	config: {
		scrollable: {
			direction: 'vertical',
			directionLock: true
		},
		maxWidth: 360,
		maxHeight: 640,
		hideOnMaskTap: true,
		layout: 'vbox'
	},

	initialize: function (args) {
		this.callParent(args);

		this.setStyle({
			'font-size': '110%',
			'border-color': 'black',
			'margin-bottom': '18px',
			'height': '79%',
			'width': '95%'
		});

		this.toolbar = Ext.create('Ext.Toolbar', {
			title: Messages.ANSWER_PREVIEW_DIALOGBOX_TITLE,
			docked: 'top',
			ui: 'light',
			items: [{
				xtype: 'button',
				iconCls: 'icon-close',
				handler: this.hide,
				scope: this,
				style: {
					'height': '36px',
					'font-size': '0.9em',
					'padding': '0 0.4em'
				}
			}, {xtype: 'spacer'},
				this.statisticButton = Ext.create('Ext.Button', {
					iconCls: 'icon-chart',
					style: 'padding: 0 0.4em',
					handler: this.statisticsButtonHandler,
					scope: this
				})
			]
		});

		this.confirmButton = Ext.create('Ext.Container', {
			layout: {
				pack: 'center',
				type: 'hbox'
			},
			items: [
				Ext.create('Ext.Button', {
					text: Messages.QUESTION_PREVIEW_DIALOGBOX_BUTTON_TITLE,
					ui: 'confirm',
					style: 'width: 80%; maxWidth: 250px; margin-top: 10px;',
					scope: this,
					handler: function () {
						this.hide();
					}
				})
			]
		});

		// Create standard panel with framework support
		this.questionPanel = Ext.create('ARSnova.view.MathJaxMarkDownPanel', {
			cls: "roundedBox",
			style: 'min-height: 82px;'
		});

		// answer preview box content panel
		this.mainPanel = Ext.create('Ext.Container', {
			layout: 'vbox',
			style: 'margin-bottom: 10px;',
			styleHtmlContent: true,
			items: [this.questionPanel]
		});

		// remove padding around mainPanel
		this.mainPanel.bodyElement.dom.style.padding = "0";

		this.on('hide', function () {
			ARSnova.app.innerScrollPanel = false;
			ARSnova.app.activePreviewPanel = false;
			this.destroy();
		});

		this.on('painted', function () {
			ARSnova.app.innerScrollPanel = this;
			ARSnova.app.activePreviewPanel = this;
		});

		this.add([
			this.toolbar,
			this.mainPanel
		]);
	},

	showPreview: function (options) {
		this.answers = options.answers;
		this.content = options.content;
		this.setQuestionPanelContent(options.title, options.content);

		if (options.image) {
			this.grid = Ext.create('ARSnova.view.components.GridImageContainer', {
				itemId: 'previewGridImageContainer',
				customWindowWidth: this.getMaxWidth(),
				gridIsHidden: true,
				editable: false
			});

			this.grid.setImage(options.image);
			this.mainPanel.add(this.grid);
		}

		this.statisticButton.setHidden(
			options.questionType === 'grid' ||
			options.questionType === 'flashcard'
		);

		if (options.questionType === 'grid') {
			if (options.image) {
				this.grid.setGridIsHidden(false);
				this.grid.setEditable(true);
			}
		} else if (options.questionType === 'flashcard') {
			var answerPanel = Ext.create('ARSnova.view.MathJaxMarkDownPanel', {
				style: 'word-wrap: break-word;',
				cls: ''
			});

			this.answerList = Ext.create('Ext.Container', {
				layout: 'vbox',
				cls: 'roundedBox',
				hidden: true,
				style: 'margin-bottom: 10px;',
				styleHtmlContent: true
			});

			this.answerList.add(answerPanel);
			answerPanel.setContent(this.answers[0].text, true, true);

			var flashcardButton = {
				xtype: 'button',
				cls: 'login-button',
				ui: 'confirm',
				text: Messages.SHOW_FLASHCARD_ANSWER,
				handler: function (button) {
					if (this.answerList.isHidden()) {
						this.answerList.show();
						button.setText(Messages.HIDE_FLASHCARD_ANSWER);
					} else {
						this.answerList.hide();
						button.setText(Messages.SHOW_FLASHCARD_ANSWER);
					}
				},
				scope: this
			};

			this.mainPanel.add([flashcardButton, this.answerList]);
		} else {
			this.answerList = Ext.create('ARSnova.view.components.List', {
				store: Ext.create('Ext.data.Store', {
					model: 'ARSnova.model.Answer'
				}),

				cls: 'roundedBox',
				itemHeight: '32px',
				itemCls: 'arsnova-mathdown x-html answerListButton noPadding',
				itemTpl: new Ext.XTemplate(
					"<tpl if='this.isFormattedStringEmpty(formattedText) === true'>",
						"&nbsp;",
					"<tpl else>",
						'<tpl if="correct === true">',
							'<span class="answerOptionItem answerOptionCorrectItem">&nbsp;</span>',
						'<tpl else>',
							'<span class="answerOptionItem">&nbsp;</span>',
						'</tpl>',
						'<span class="answerOptionText">{formattedText}</span>',
					"</tpl>",
					{
						isFormattedStringEmpty: function (formattedString) {
							if (formattedString === "") {
								return true;
							} else {
								return false;
							}
						}
					}
				)
			});

			this.answerList.getStore().add(this.answers);
			this.answerList.getStore().each(function (item) {
				if (ARSnova.app.globalConfig.parseAnswerOptionFormatting) {
					var md = Ext.create('ARSnova.view.MathJaxMarkDownPanel');
					md.setContent(item.get('text'), true, true, function (html) {
						item.set('formattedText', html.getHtml());
						md.destroy();
					});
				} else {
					item.set('formattedText', Ext.util.Format.htmlEncode(item.get('text')));
				}
			});

			this.mainPanel.add([this.answerList]);
		}

		this.mainPanel.add([
			this.confirmButton
		]);

		this.show();

		// for IE: unblock input fields
		Ext.util.InputBlocker.unblockInputs();
	},

	setQuestionPanelContent: function (title, content) {
		var questionString;
		// Setup question title and text to display in the same field; markdown handles HTML encoding

		if (title.length === 0) {
			this.questionPanel.removeCls('allCapsHeader');
			questionString = content;
		} else {
			this.questionPanel.addCls('allCapsHeader');
			questionString = title.replace(/\./, "\\.")
				+ '\n\n' // inserts one blank line between subject and text
				+ content;
		}

		this.questionPanel.setContent(questionString, true, true);
	},

	statisticsButtonHandler: function () {
		var questionObj = {};
		questionObj.possibleAnswers = this.answers;
		questionObj.text = this.content;

		this.questionStatisticChart = Ext.create('ARSnova.view.AnswerPreviewStatisticChart', {
			question: questionObj,
			lastPanel: this
		});

		this.remove(this.toolbar, false);
		this.remove(this.mainPanel, false);
		this.setScrollable(false);

		this.add([
			this.questionStatisticChart
		]);
	},

	showEmbeddedPagePreview: function (embeddedPage) {
		var controller = ARSnova.app.getController('Application'),
			me = this;

		this.setHideOnMaskTap(false);

		// remove default elements from preview
		this.remove(this.toolbar, false);
		this.remove(this.mainPanel, false);

		embeddedPage.setBackHandler(function () {
			me.setHideOnMaskTap(true);

			// toggle hrefPanelActive();
			controller.toggleHrefPanelActive();

			// remove & destroy embeddedPage and delete reference
			me.remove(embeddedPage, true);
			delete controller.embeddedPage;

			// add default elements to preview
			me.add(me.toolbar);
			me.add(me.mainPanel);
		});

		// add embeddedPage to preview
		this.add(embeddedPage);
	}
});
